/******/ (() => { // webpackBootstrap
/******/ 	"use strict";
var __webpack_exports__ = {};

;// CONCATENATED MODULE: ./assets/app/dev/public/services/alerts.service.ts
function alertsService() {
  var _this = this;

  /**
   * Entire list of alerts.
   */
  this.list = [];
  /**
   * Add an alert to the list of alerts.
   *
   * @param {Object} options
   * @param {string} options.type
   * @param {string} options.msg
   */

  this.add = function (options) {
    if (!angular.isObject(options)) {
      options = {
        type: 'warning',
        msg: options
      };
    }

    _this.list.push(options);
  };
  /**
   * Add error message to list.
   *
   * @param {string} msg
   */


  this.error = function (msg) {
    _this.list.push({
      type: 'danger',
      msg: msg
    });
  };
  /**
   * Add warning message to list.
   *
   * @param {string} msg
   */


  this.warning = function (msg) {
    _this.list.push({
      type: 'warning',
      msg: msg
    });
  };
  /**
   * Add info message to list.
   *
   * @param {string} msg
   */


  this.info = function (msg) {
    _this.list.push({
      type: 'info',
      msg: msg
    });
  };
  /**
   * Default action: Add success message to list.
   *
   * @param {string} msg
   */


  this.message = function (msg) {
    _this.info(msg);
  };
  /**
   * Add success message to list.
   *
   * @param {string} msg
   */


  this.success = function (msg) {
    _this.list.push({
      type: 'success',
      msg: msg
    });
  };
  /**
   * Remove message from list.
   *
   * @param {number} index
   */


  this.remove = function (index) {
    _this.list.splice(index, 1);
  };
}
;// CONCATENATED MODULE: ./assets/app/dev/public/services/analytics.service.ts
function analyticsService() {
  var self = this;
  window.dataLayer = window.dataLayer || [];

  function gtag() {
    dataLayer.push(arguments);
  }

  gtag('js', new Date());

  try {
    if (localized.settings.analytics.UA.enabled) {
      self.UAEnabled = true;
      gtag('config', localized.settings.analytics.UA.id);
    } else {
      self.UAEnabled = false;
    }
  } catch (e) {
    console.warn(e.message);
    self.UAEnabled = false;
  }

  try {
    if (localized.settings.analytics.AW.enabled) {
      self.AWEnabled = true;
      gtag('config', localized.settings.analytics.AW.id);
    } else {
      self.AWEnabled = false;
    }

    if (localized.settings.analytics.conversions.phone.enabled) {
      gtag('config', localized.settings.analytics.AW.id + '/' + localized.settings.analytics.conversions.phone.tag, {
        phone_conversion_number: localized.settings.analytics.conversions.phone.number
      });
    }
  } catch (e) {
    console.warn(e.message);
    self.AWEnabled = false;
  }
  /**
   * Send any event
   *
   * @function
   * @param {string} action
   * @param {Object} data
   */


  self.reportEvent = function (action, data) {
    if (self.UAEnabled || self.AWEnabled) {
      try {
        gtag('event', action, data);
      } catch (e) {
        console.warn(e.message);
      }
    }
  };
  /**
   * Add to Cart event
   *
   * @function
   * @param {Object} cart             - Contains the data for sending to analytics for add to cart
   * @param {float}  cart.added_value - The combined value of all items added to cart
   * @param {Object} cart.added_items - All of the items added to the cart
   */


  self.addToCart = function (cart) {
    try {
      self.reportEvent('add_to_cart', {
        currency: 'USD',
        value: cart.added_value,
        items: cart.added_items
      });
    } catch (e) {
      console.warn(e.message);
    }
  };
  /**
   * Begin Checkout event
   *
   * @function
   * @param {Object} order
   * @param {float}  order.order.total_amt - The total value of order before tax/shipping calculations
   * @param {Object} order.checkout_items  - The line items of the order
   */


  self.beginCheckout = function (order) {
    try {
      self.reportEvent('begin_checkout', {
        currency: 'USD',
        value: order.order.total_amt,
        items: order.checkout_items
      });
    } catch (e) {
      console.warn(e.message);
    }
  };
  /**
   * Login event
   *
   * @function
   */


  self.login = function () {
    try {
      self.reportEvent('login', {
        method: 'VendorFuel'
      });
    } catch (e) {
      console.warn(e.message);
    }
  };
  /**
   * Purchase event
   *
   * @function
   * @param {Object}  order
   * @param {float}   order.order_info.total_amt
   * @param {integer} order.order_info.order_id
   * @param {float}   order.order_info.tax
   * @param {float}   order.order_info.shipping
   * @param {Object}  order.purchased_items
   */


  self.purchase = function (order) {
    try {
      if (localized.settings.analytics.UA.enabled) {
        self.reportEvent('purchase', {
          currency: 'USD',
          affiliation: 'VendorFuel online store',
          value: order.order_info.total_amt,
          transaction_id: order.order_info.order_id,
          tax: order.order_info.tax,
          shipping: order.order_info.shipping,
          items: order.purchased_items
        });
      }

      if (localized.settings.analytics.AW.enabled && localized.settings.analytics.conversions.purchase.enabled) {
        self.reportEvent('conversion', {
          send_to: localized.settings.analytics.AW.id + '/' + localized.settings.analytics.conversions.purchase.tag,
          transaction_id: order.order_info.order_id,
          currency: 'USD',
          value: order.order_info.total_amt
        });
      }
    } catch (e) {
      console.warn(e.message);
    }
  };
  /**
   * Remove From Cart event
   *
   * @function
   * @param {Object} cart               - Contains the data for sending to analytics for remove from cart
   * @param {float}  cart.removed_value - The combined value of all items removed from cart
   * @param {Object} cart.removed_items - All of the items removed from the cart
   */


  self.removeFromCart = function (cart) {
    try {
      self.reportEvent('remove_from_cart', {
        currency: 'USD',
        value: cart.removed_value,
        items: cart.removed_items
      });
    } catch (e) {
      console.warn(e.message);
    }
  };
  /**
   * Search event
   *
   * @function
   * @param {string} term - The term that was searched for
   */


  self.search = function (term) {
    try {
      if ((term === null || term === void 0 ? void 0 : term.length) > 0) {
        self.reportEvent('search', {
          search_term: term
        });
      }
    } catch (e) {
      console.warn(e.message);
    }
  };
  /**
   * Sign Up event
   *
   * @function
   */


  self.signUp = function () {
    try {
      self.reportEvent('sign_up', {
        method: 'VendorFuel'
      });
    } catch (e) {
      console.warn(e.message);
    }
  };
  /**
   * View Item event
   *
   * @function
   * @param {Object} product - The product that was retrieved.
   */


  self.viewItem = function (product) {
    try {
      self.reportEvent('view_item', {
        items: [{
          id: product.sku,
          name: product.description,
          list_name: 'Product Details',
          brand: product.manufacturer,
          category: product.cat_title,
          price: product.price
        }]
      });
    } catch (e) {
      console.warn(e.message);
    }
  };
  /**
   * View Search Results event
   *
   * @function
   * @param {string} term     - The term that was searched for
   * @param {Object} products - The products return from this search.
   */


  self.viewSearchResults = function (term, products) {
    try {
      var reportProducts = [];

      for (var i = 0; i < products.length; i++) {
        var product = products[i];
        reportProducts[i] = {
          id: product.sku,
          name: product.description,
          list_name: 'Search Results',
          brand: product.manufacturer ? product.manufacturer : null,
          category: product.category ? product.category.title : null,
          list_position: i,
          price: product.price
        };
      }

      self.reportEvent('view_search_results', {
        search_term: term,
        items: reportProducts
      });
    } catch (e) {
      console.warn(e.message);
    }
  };
}
;// CONCATENATED MODULE: ./assets/app/dev/public/services/auth.service.ts
authService.$inject = ['$cookies', '$window'];
function authService($cookies, $window) {
  var self = this;
  /**
   * Parse a JWT.
   *
   * @param {string} token
   * @return {string}
   */

  self.parseJWT = function (token) {
    var base64Url = token.split('.')[1];
    var base64 = base64Url.replace('-', '+').replace('_', '/');
    return JSON.parse($window.atob(base64));
  };
  /**
   * Save auth token and remember for 14 days if 'remember' is true.
   *
   * @param {string}  token
   * @param {boolean} remember
   * @return {string}
   */


  self.saveToken = function (token, remember) {
    var cookieOptions = {
      samesite: 'none',
      secure: true,
      path: '/'
    };

    if (remember) {
      var currentTime = new Date();
      currentTime.setDate(currentTime.getDate() + 14);
      cookieOptions = {
        samesite: 'none',
        secure: true,
        path: '/',
        expires: currentTime
      };
    }

    $cookies.put('vf.auth.token', token, cookieOptions);
  };
  /**
   * Retrieve auth token.
   *
   * @return {string}
   */


  self.getToken = function () {
    return $cookies.get('vf.auth.token');
  };
  /**
   * Retrieve Admin auth token A.
   *
   * @return {string}
   */


  self.getAdminTokenA = function () {
    return $cookies.get('vendorfuel-admin-tokena');
  };
  /**
   * Retrieve Admin auth token A.
   *
   * @return {string}
   */


  self.getAdminTokenB = function () {
    return $cookies.get('vendorfuel-admin-tokenb');
  };

  self.getAdminJWT = function () {
    return $cookies.get('vendorfuel-admin-token');
  };
  /**
   * Verify token is valid for authentication.
   *
   * @param {string} token
   * @return {boolean}
   */


  self.isAuthed = function (token) {
    token = token || self.getToken();

    if (token) {
      return !self.tokenExpired();
    }

    return false;
  };
  /**
   * Check for expired token.
   *
   * @param {string} token
   * @return {boolean}
   */


  self.tokenExpired = function () {
    return false;
  };
  /**
   * Clear auth token and stored auth info.
   */


  self.clearToken = function () {
    $cookies.remove('vf.user.name', {
      samesite: 'none',
      secure: true,
      path: '/'
    });
    $cookies.remove('vf.user.email', {
      samesite: 'none',
      secure: true,
      path: '/'
    });
    $cookies.remove('vf.user.group_admin', {
      samesite: 'none',
      secure: true,
      path: '/'
    });
    $cookies.remove('vf.user.approver', {
      samesite: 'none',
      secure: true,
      path: '/'
    });
    $cookies.remove('vf.user.is-guest', {
      samesite: 'none',
      secure: true,
      path: '/'
    });
    $cookies.remove('vf.user.group', {
      samesite: 'none',
      secure: true,
      path: '/'
    });
    $cookies.remove('vf.user.remember', {
      samesite: 'none',
      secure: true,
      path: '/'
    });
    $cookies.remove('vf.user.last_login', {
      samesite: 'none',
      secure: true,
      path: '/'
    });
    $cookies.remove('vf.cart.cartCount', {
      samesite: 'none',
      secure: true,
      path: '/'
    });
    $cookies.remove('vf.user.punchoutOnly', {
      samesite: 'none',
      secure: true,
      path: '/'
    });
    $cookies.remove('vf.user.mixedPunchout', {
      samesite: 'none',
      secure: true,
      path: '/'
    });
    $cookies.remove('vf.user.company', {
      samesite: 'none',
      secure: true,
      path: '/'
    });
    $cookies.remove('vf.user.defaultShippingProfile', {
      samesite: 'none',
      secure: true,
      path: '/'
    });
    $cookies.remove('vf.user.defaultBillingProfile', {
      samesite: 'none',
      secure: true,
      path: '/'
    });
    $cookies.remove('vf.user.group_id', {
      samesite: 'none',
      secure: true,
      path: '/'
    });
    $cookies.remove('vf.user.group_parent_id', {
      samesite: 'none',
      secure: true,
      path: '/'
    });
    $cookies.remove('vf.user.price_availability', {
      samesite: 'none',
      secure: true,
      path: '/'
    });
    $cookies.remove('vf.user.cost_center_is_required', {
      samesite: 'none',
      secure: true,
      path: '/'
    });
    $cookies.remove('vf.user.currentGroup_id', {
      samesite: 'none',
      secure: true,
      path: '/'
    });
    $cookies.remove('vf.cart', {
      samesite: 'none',
      secure: true,
      path: '/'
    });
    $cookies.remove('vf.auth.token', {
      samesite: 'none',
      secure: true,
      path: '/'
    });
    $cookies.remove('vf.cart.cartCount', {
      samesite: 'none',
      secure: true,
      path: '/'
    });
    $cookies.remove('force_password', {
      samesite: 'none',
      secure: true,
      path: '/'
    });
  };
}
;// CONCATENATED MODULE: ./assets/app/dev/public/common/format-url-params.ts
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function formatURLParams(href, params) {
  var url = new URL(href);
  Object.entries(params).forEach(function (entry) {
    var _entry = _slicedToArray(entry, 2),
        key = _entry[0],
        value = _entry[1];

    url.searchParams.set(key, value);
  });
  return url.href;
}
;// CONCATENATED MODULE: ./assets/app/dev/public/common/get-int-from-cookie.ts
function getIntFromCookie(cookie) {
  var ret = parseInt(cookie);

  if (isNaN(ret)) {
    ret = 0;
  }

  return ret;
}
;// CONCATENATED MODULE: ./assets/app/dev/public/services/cart.service.ts


cartService.$inject = ['$cookies', '$http', '$q', 'Alerts', 'Analytics', 'Debug', 'User', 'Utils'];
function cartService($cookies, $http, $q, Alerts, Analytics, Debug, User, Utils) {
  // TODO: Good integration with api so cart and service have the same data.
  // TODO: Setup watching sessionStorage variable for changes, and updating in other tabs...
  var self = this;
  self.details = null;
  self.shipping_methods = null;

  try {
    self.items = JSON.parse($cookies.get('vf.cart'));
  } catch (e) {
    self.items = {};
  }

  self.cartCount = getIntFromCookie($cookies.get('vf.cart.cartCount'));
  self.zipCode = getIntFromCookie($cookies.get('vf.cart.zip'));
  self.county = $cookies.get('vf.cart.county');
  self.selectedShipping = getIntFromCookie($cookies.get('vf.cart.selectedShipping'));
  self.squareUpPaymentForm = null;
  self.paymentMethod = null;
  self.sandboxEnabled = false;
  self.user = User;
  self.squareUpAppID = null;

  self.authorizeCard = function () {
    switch (self.getPaymentMethod()) {
      case 'squareup':
        self.squareUpPaymentForm.requestCardNonce();
        break;
    }
  };

  self.getPaymentMethod = function () {
    return self.paymentMethod;
  };

  self.setPaymentMethod = function (payment_method) {
    self.paymentMethod = payment_method;
  };

  self.getShippingMethodID = function () {
    return self.selectedShippingMethodID;
  };

  self.setShippingMethodID = function (shipping_method_id) {
    self.selectedShippingMethodID = shipping_method_id;
  };

  self.loadPaymentForm = function () {};

  self.getAuthnetPaymentFormTemplate = function () {
    return 'https://api.vendorfuel.com/assets/templates/authnet-payment-form.html';
  };

  self.getSquareUpApplicationID = function () {
    if (!self.sandboxEnabled) {
      return 'sq0idp-XSN1fN7oGs4Q2Unob4UfSQ';
    }

    return 'sandbox-sq0idb-7JFysyB76m-8lyoWdvkp2Q';
  };

  self.getSquareUpPaymentFormTemplate = function () {
    return 'https://api.vendorfuel.com/assets/templates/squareup-payment-form.html';
  };

  self.loadSquareUpPaymentForm = function () {
    self.setPaymentMethod('squareup');

    if (!self.squareUpPaymentForm) {
      self.squareUpPaymentForm = new SqPaymentForm({
        // Initialize the payment form elements
        applicationId: self.getSquareUpApplicationID(),
        inputClass: 'sq-input',
        autoBuild: false,
        // Customize the CSS for SqPaymentForm iframe elements
        inputStyles: [{
          fontSize: '16px',
          lineHeight: '24px',
          padding: '16px',
          placeholderColor: '#a0a0a0',
          backgroundColor: 'transparent'
        }],
        // Initialize the credit card placeholders
        cardNumber: {
          elementId: 'sq-card-number',
          placeholder: 'Card Number'
        },
        cvv: {
          elementId: 'sq-cvv',
          placeholder: 'CVV'
        },
        expirationDate: {
          elementId: 'sq-expiration-date',
          placeholder: 'MM/YY'
        },
        postalCode: {
          elementId: 'sq-postal-code',
          placeholder: 'Postal'
        },
        // SqPaymentForm callback functions
        callbacks: {
          /*
                         * callback function: cardNonceResponseReceived
                         * Triggered when: SqPaymentForm completes a card nonce request
                         */
          cardNonceResponseReceived: function cardNonceResponseReceived(errors, nonce, cardData) {
            if (errors) {
              // Log errors from nonce generation to the browser developer console.
              console.error('Encountered errors:');
              errors.forEach(function (error) {
                console.error('  ' + error.message);
              });
              alert('Encountered errors, check browser developer console for more details');
              return;
            }

            Debug.log(cardData); //TODO: Replace alert with code in step 2.1

            self.sq_nonce = nonce;
            $scope.payment_info.cc_type = cardData.card_brand;
            $scope.payment_info.cc_num = cardData.last_4;
            self.completeOrder();
          }
        }
      });
      self.squareUpPaymentForm.build();
    }
  };

  var updateStorage = function updateStorage() {
    $cookies.put('vf.cart', JSON.stringify(self.items), {
      samesite: 'none',
      secure: true,
      path: '/'
    });
  };

  var setSelectedShippingToDefault = function setSelectedShippingToDefault() {
    for (var id in self.shipping_methods) {
      if (Object.prototype.hasOwnProperty.call(self.shipping_methods, id)) {
        Debug.log(id);
        $cookies.put('vf.cart.selectedShipping', id, {
          samesite: 'none',
          secure: true,
          path: '/'
        });
        self.selectedShipping = id;
        return id;
      }
    }
  };

  self.updateFromApi = function (data) {
    self.details = data.cart;
    self.shipping_methods = data.shipping_methods;

    if (!angular.isUndefined(data.cart_count)) {
      self.cartCount = getIntFromCookie(data.cart_count);
      $cookies.put('vf.cart.cartCount', data.cart_count, {
        samesite: 'none',
        secure: true,
        path: '/'
      });
    } else {
      $cookies.put('vf.cart.cartCount', 0, {
        samesite: 'none',
        secure: true,
        path: '/'
      });
    }

    self.items = {};

    if (self.cartCount > 0 && self.details) {
      angular.forEach(self.details.items, function (item, key) {
        self.items[key] = item.qty;
      });
    }

    updateStorage();
  };
  /**
   * Adding multiple items to the cart.
   *
   * @param {Object} products The keys are product ids and the values are the qtys.
   * @return {unresolved}
   */


  self.addItems = function (products) {
    // Because of the way the api is currently reading the ids and qtys, we have to re-arrange things here.
    // Api should be fixed to instead accept an associative array of id->qty ...
    var ids = [];
    var paramData = {}; // setting up values to pass to api

    angular.forEach(products, function (qty, id) {
      ids.push(id);
      products[id] = parseInt(qty);
    });

    if (ids.length < 1) {
      return $q.when(false);
    } else if (ids.length === 1) {
      paramData.product_id = ids[0];
      paramData.qty = products[ids[0]];
    } else {
      paramData.product_id = ids;
      paramData.qty = products;
    } // make sure the user is logged in before continuing


    var loginCheck;

    if (!User.isAuthed) {
      loginCheck = User.guestLogin();
    } else {
      loginCheck = $q.when(true);
    }

    return loginCheck.then(function (resp) {
      if (resp.data && resp.data.errors && resp.data.errors.length) {
        return resp;
      } // add to cart


      return $http.post(localized.apiURL + '/cart/add', paramData);
    }).then(function (resp) {
      if (resp.data && resp.data.errors && resp.data.errors.length) {
        return resp;
      }

      angular.forEach(products, function (qty, id) {
        // Successfully added to cart
        if (angular.isUndefined(self.items[id])) {
          self.items[id] = 0;
        }

        self.items[id] += qty;
        self.cartCount += qty;
      });
      self.updateFromApi(resp.data);
      Analytics.addToCart(resp.data);

      if (localized.settings.general.redirectToCart) {
        Utils.goToPage('cart');
      }

      return resp;
    });
  };
  /**
   * Add an item to the cart.
   *
   * @param {number} productId
   * @param {number} qty
   * @return {unresolved}
   */


  self.add = function (productId, qty) {
    var products = {};
    products[productId] = qty;
    return self.addItems(products);
  };
  /**
   * Remove item(s) from the cart.
   *
   * @param {number | Array} productId
   * @return {unresolved}
   */


  self.remove = function (productId) {
    return $http.post(localized.apiURL + '/cart/remove', {
      product_id: productId
    }).then(function (resp) {
      if (self.details) {
        delete self.details.items[productId];
        Analytics.removeFromCart(resp.data);
        return self.update();
      }

      return resp;
    });
  };
  /**
   * Update quantities in the cart. The qty argument is only a guard for preventing the update
   * when an empty string is passed in.
   *
   * @param {number | string} qty (Optional)
   * @return {unresolved}
   */


  self.update = function (qty, product_id) {
    if (qty === '') {
      // Empty string, don't update cart until a qty is actually entered.
      // undefined qty will still call update with qty of 1
      // this just sets a guard on entering a qty, so backspace can be used if fields
      return $q.when(false);
    }

    if (typeof product_id === 'undefined') {
      return $q.when(false);
    }

    self.details.items[product_id].qty = qty;
    return $http.post(localized.apiURL + '/cart/update', {
      items: JSON.stringify(self.details.items[product_id])
    }).then(function (resp) {
      self.updateFromApi(resp.data);
      return resp;
    });
  };
  /**
   * Clear out the cart.
   *
   * @return {unresolved}
   */


  self.clear = function () {
    return $http.post(localized.apiURL + '/cart/clear').then(function (resp) {
      self.updateFromApi(resp.data);
      return resp;
    });
  };
  /**
   * Clear out the cart.
   *
   * @return {unresolved}
   */


  self.quote = function (name, contact) {
    return $http.post(localized.apiURL + '/cart/request-quote', {
      name: name,
      contact: contact
    });
  };

  self.csv = function () {
    $http.post(localized.apiURL + '/cart/csv');
  };
  /**
   * Get the qty for a product id.
   *
   * @param {number} productId
   * @return {number}
   */


  self.getQty = function (productId) {
    return self.items[productId] || 0;
  };
  /**
   * Get and fill the cart details into this service.
   *
   * @return {unresolved}
   */


  self.fillDetails = function () {
    var params = {};
    params.zipcode = self.zipCode;
    params.county = self.county;
    params.shipping_method = self.selectedShipping;
    return $http.get(formatURLParams(localized.apiURL + '/cart/view', params)).then(function (resp) {
      self.updateFromApi(resp.data);

      if (!self.selectedShipping) {
        setSelectedShippingToDefault();
      } // TODO: if multiple tax_counties in resp, show pick county dialog...


      return resp;
    });
  }; // TODO: Move saved cart functionality to a seperate 'SavedCart' service.?

  /**
   * Store a copy of the current cart with the given title.
   *
   * @param {string} cartTitle
   */


  this.save = function (cartTitle) {
    var url = "".concat(localized.apiURL, "/cart/saved/modify");
    var data = {
      cart_title: cartTitle
    };
    return $http.post(url, data).then(function (response) {
      if (!response.data.saved_cart_id) {
        return $q.reject(response);
      }

      url = "".concat(localized.apiURL, "/cart/saved/item/add");
      var paramData = {
        saved_cart_id: response.data.saved_cart_id,
        product_id: [],
        qty: {}
      };
      angular.forEach(self.items, function (qty, id) {
        paramData.product_id.push(id);
        paramData.qty[id] = qty;
      });
      return $http.post(url, paramData).then(function (addResp) {
        Alerts.message('Cart has been saved.');
        return addResp;
      });
    });
  };
  /**
   * Get a list of saved carts.
   *
   */


  this.getSavedList = function () {
    var url = "".concat(localized.apiURL, "/cart/saved/list");
    return $http.get(url).then(function (response) {
      return response.data.saved_carts;
    });
  };
  /**
   * Get a saved cart.
   *
   * @param {number} savedCartId
   * @return {unresolved}
   */


  self.getSaved = function (savedCartId) {
    return $http.get(formatURLParams(localized.apiURL + '/cart/saved/view', {
      saved_cart_id: savedCartId
    })).then(function (resp) {
      return {
        cart_title: resp.data.cart_title,
        saved_cart_id: resp.data.saved_cart_id,
        subtotal: resp.data.subtotal,
        items: resp.data.items
      };
    });
  };

  self.getFavorites = function () {
    return $http.post(localized.apiURL + '/cart/favorites/view', {}).then(function (resp) {
      return resp;
    });
  };

  self.addFavorite = function (params) {
    return $http.post(localized.apiURL + '/cart/favorites/add', params).then(function (resp) {
      return resp;
    });
  };

  self.removeFavorite = function (params) {
    return $http.post(localized.apiURL + '/cart/favorites/remove', params).then(function (resp) {
      return resp;
    });
  };
  /**
   * Delete a saved cart.
   *
   * @param {number} savedCartId
   * @return {unresolved}
   */


  self.deleteSaved = function (savedCartId) {
    return $http.post(localized.apiURL + '/cart/saved/remove', {
      saved_cart_id: savedCartId
    });
  };
  /**
   * Remove an item from the specified saved cart.
   *
   * @param {number} savedCartId
   * @param {number} productId
   * @return {unresolved}
   */


  self.removeSavedItem = function (savedCartId, productId) {
    return $http.post(localized.apiURL + '/cart/saved/item/remove', {
      product_id: productId,
      saved_cart_id: savedCartId
    });
  };

  self.addPromoCode = function (promoCode) {
    if (angular.isUndefined(promoCode) || promoCode.length < 1) {
      return $q.when(false);
    }

    return $http.post(localized.apiURL + '/cart/promo-code/add', {
      promo_code: promoCode
    }).then(function (resp) {
      if (resp.data.promo_code_id) {
        self.updateFromApi(resp.data);
      }

      return resp;
    });
  };

  self.removePromoCode = function (promoCodeId) {
    return $http.post(localized.apiURL + '/cart/promo-code/remove', {
      promo_code_id: promoCodeId
    }).then(function (resp) {
      if (resp.data.promo_code_id) {
        self.updateFromApi(resp.data);
      }

      return resp;
    });
  };

  self.setZip = function (zip) {
    $cookies.put('vf.cart.zip', zip, {
      samesite: 'none',
      secure: true,
      path: '/'
    });
    self.zipCode = zip;
    return self.fillDetails().then(function (resp) {
      if (!self.selectedShipping) {
        setSelectedShippingToDefault();
      }

      return resp;
    });
  };

  self.setCounty = function (county) {
    $cookies.put('vf.cart.county', county, {
      samesite: 'none',
      secure: true,
      path: '/'
    });
    self.county = county;
    return self.fillDetails();
  };

  self.setSelectedShipping = function (selectedShipping) {
    $cookies.put('vf.cart.selectedShipping', selectedShipping, {
      samesite: 'none',
      secure: true,
      path: '/'
    });
    self.selectedShipping = selectedShipping;
  };

  self.clearShipping = function () {
    $cookies.remove('vf.cart.zip', {
      samesite: 'none',
      secure: true,
      path: '/'
    });
    delete self.zipCode;
    $cookies.remove('vf.cart.county', {
      samesite: 'none',
      secure: true,
      path: '/'
    });
    delete self.county;
    setSelectedShippingToDefault();
    return $q.when(true);
  };

  self.partialCheckout = function (items) {
    Debug.log(items);
    var totalCheck = 0;
    angular.forEach(items, function (qty) {
      totalCheck += qty;
    });

    if (totalCheck === 0) {
      Alerts.message('You must include at least one item to checkout.');
    } else {
      $cookies.put('vf.cart.partial', JSON.stringify(items), {
        samesite: 'none',
        secure: true,
        path: '/'
      });
    }

    return $q.when(true);
  };

  self.addBySku = function (sku, qty) {
    qty = parseInt(qty) || 1;
    return $http.post(localized.apiURL + '/cart/add-sku', {
      sku: sku,
      qty: qty
    }).then(function (resp) {
      Debug.log(resp);
      return resp;
    });
  };

  self.getShippingMethods = function (order_id, profile_id, zipcode) {
    var params = {
      order_id: order_id,
      shipping_id: profile_id,
      zipcode: zipcode
    };
    return $http.post(localized.apiURL + '/cart/order/shipping/methods', params).then(function (resp) {
      return resp;
    });
  };

  self.checkout = function (paypal, return_url, cancel_url, shipping_id) {
    var params = {};

    if (typeof paypal !== 'undefined') {
      params.paypal = paypal;
      params.return_url = return_url;
      params.cancel_url = cancel_url;
    }

    if ($cookies.get('vf.cart.partial') !== null) {
      try {
        params.items = JSON.parse($cookies.get('vf.cart.partial'));
      } catch (e) {
        params.items = {};
      }
    }

    if (shipping_id) {
      params.shipping_id = shipping_id;
    }

    return $http.post(localized.apiURL + '/cart/checkout', params).then(function (resp) {
      $cookies.put('vf.cart.partial', null, {
        samesite: 'none',
        secure: true,
        path: '/'
      });
      Analytics.beginCheckout(resp.data);
      return resp;
    });
  };

  self.priceAvailabilityResponse = function (order, price_availability_response, reconfirm) {
    var params = {};
    params.order_id = order.order.order_id;
    params.return_url = order.return_url;
    params.price_availability_response = price_availability_response;
    params.reconfirm = reconfirm;
    return $http.post(localized.apiURL + '/cart/order/price-availability', params).then(function (resp) {
      return resp;
    });
  };

  self.confirmOrder = function (checkout_info) {
    var params = {};
    params.shipping_id = checkout_info.selected_shipping_profile.shipping_id;
    params.billing_id = checkout_info.selected_billing_profile.billing_id;
    params.order_id = checkout_info.order.order_id;
    params.shipping_method = checkout_info.selected_shipping_method;
    params.shipping_first_name = checkout_info.shipping_first_name;
    params.shipping_last_name = checkout_info.shipping_last_name;
    params.shipping_email = checkout_info.shipping_email;
    params.shipping_address1 = checkout_info.shipping_address1;
    params.shipping_address2 = checkout_info.shipping_address2;
    params.shipping_city = checkout_info.shipping_city;
    params.shipping_state = checkout_info.shipping_state;
    params.shipping_zip = checkout_info.shipping_zip;
    params.shipping_phone = checkout_info.shipping_phone;
    params.billing_first_name = checkout_info.billing_first_name;
    params.billing_last_name = checkout_info.billing_last_name;
    params.billing_email = checkout_info.billing_email;
    params.billing_address1 = checkout_info.billing_address1;
    params.billing_address2 = checkout_info.billing_address2;
    params.billing_city = checkout_info.billing_city;
    params.billing_state = checkout_info.billing_state;
    params.billing_zip = checkout_info.billing_zip;
    params.billing_phone = checkout_info.billing_phone;
    params.return_url = checkout_info.return_url;

    if (localized.settings.general.checkout.company_name_option) {
      params.organization = checkout_info.extraFields.organization;
    }

    if (localized.settings.general.checkout.purchase_order_option) {
      params.rr_po_num = checkout_info.extraFields.rr_po_num;
    }

    if (localized.settings.general.checkout.issuing_office_option) {
      params.issuing_office = checkout_info.extraFields.issuing_office;
    }

    if (localized.settings.general.checkout.cost_center_option) {
      params.cost_center_code = checkout_info.extraFields.cost_center_code;
    }

    if (localized.settings.general.checkout.attention_option) {
      params.attention = checkout_info.extraFields.attention;
    }

    if (localized.settings.general.checkout.notes_option) {
      params.notes = checkout_info.extraFields.notes;
    }

    if (checkout_info.extraFields.f1 !== '') {
      params.f1 = checkout_info.extraFields.f1;
    }

    if (checkout_info.extraFields.f2 !== '') {
      params.f2 = checkout_info.extraFields.f2;
    }

    if (checkout_info.extraFields.f3 !== '') {
      params.f3 = checkout_info.extraFields.f3;
    }

    if (checkout_info.extraFields.f4 !== '') {
      params.f4 = checkout_info.extraFields.f4;
    }

    if (checkout_info.extraFields.f5 !== '') {
      params.f5 = checkout_info.extraFields.f5;
    }

    if (checkout_info.extraFields.f6 !== '') {
      params.f6 = checkout_info.extraFields.f6;
    }

    return $http.post(localized.apiURL + '/cart/order/confirm', params).then(function (resp) {
      return resp;
    });
  };

  self.confirmPaypalOrder = function (checkout_info) {
    var params = {}; //	params.shipping_id=checkout_info.selected_shipping_profile.shipping_id;
    //	params.billing_id=checkout_info.selected_billing_profile.billing_id;

    params.order_id = checkout_info.order.order_id;
    params.paypal = 1;
    params.shipping_method = checkout_info.selected_shipping_method;
    params.shipping_first_name = checkout_info.shipping_first_name;
    params.shipping_last_name = checkout_info.shipping_last_name;
    params.shipping_email = checkout_info.shipping_email;
    params.shipping_address1 = checkout_info.shipping_address1;
    params.shipping_address2 = checkout_info.shipping_address2;
    params.shipping_city = checkout_info.shipping_city;
    params.shipping_state = checkout_info.shipping_state;
    params.shipping_zip = checkout_info.shipping_zip;
    params.shipping_phone = checkout_info.shipping_phone;
    params.billing_first_name = checkout_info.billing_first_name;
    params.billing_last_name = checkout_info.billing_last_name;
    params.billing_email = checkout_info.billing_email;
    params.billing_address1 = checkout_info.billing_address1;
    params.billing_address2 = checkout_info.billing_address2;
    params.billing_city = checkout_info.billing_city;
    params.billing_state = checkout_info.billing_state;
    params.billing_zip = checkout_info.billing_zip;
    params.billing_phone = checkout_info.billing_phone;

    if (typeof checkout_info.paymentId !== 'undefined') {
      params.paymentId = checkout_info.paymentId;
    }

    if (localized.settings.general.checkout.company_name_option) {
      params.organization = checkout_info.extraFields.organization;
    }

    if (localized.settings.general.checkout.purchase_order_option) {
      params.rr_po_num = checkout_info.extraFields.rr_po_num;
    }

    if (localized.settings.general.checkout.issuing_office_option) {
      params.issuing_office = checkout_info.extraFields.issuing_office;
    }

    if (localized.settings.general.checkout.cost_center_option) {
      params.cost_center_code = checkout_info.extraFields.cost_center_code;
    }

    if (localized.settings.general.checkout.attention_option) {
      params.attention = checkout_info.extraFields.attention;
    }

    if (localized.settings.general.checkout.notes_option) {
      params.notes = checkout_info.extraFields.notes;
    }

    if (checkout_info.extraFields.f1 !== '') {
      params.f1 = checkout_info.extraFields.f1;
    }

    if (checkout_info.extraFields.f2 !== '') {
      params.f2 = checkout_info.extraFields.f2;
    }

    if (checkout_info.extraFields.f3 !== '') {
      params.f3 = checkout_info.extraFields.f3;
    }

    if (checkout_info.extraFields.f4 !== '') {
      params.f4 = checkout_info.extraFields.f4;
    }

    if (checkout_info.extraFields.f5 !== '') {
      params.f5 = checkout_info.extraFields.f5;
    }

    if (checkout_info.extraFields.f6 !== '') {
      params.f6 = checkout_info.extraFields.f6;
    }

    return $http.post(localized.apiURL + '/cart/order/confirm', params).then(function (resp) {
      return resp;
    });
  };

  self.completeOrder = function (params) {
    return $http.post(localized.apiURL + '/cart/order/complete', params).then(function (resp) {
      Analytics.purchase(resp.data);
      return resp;
    });
  };

  self.payfabricUrl = function (return_url, order_id) {
    var params = {};
    params.return_url = return_url;
    params.order_id = order_id;
    return $http.post(localized.apiURL + '/cart/order/payfabricUrl', params).then(function (resp) {
      return resp.data.payfabric_url;
    });
  };
}
;// CONCATENATED MODULE: ./assets/app/dev/public/services/checkout.service.ts
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var CheckoutService = /*#__PURE__*/function () {
  // eslint-disable-next-line no-useless-constructor
  function CheckoutService($cookies, $http, Analytics) {
    _classCallCheck(this, CheckoutService);

    this.$cookies = $cookies;
    this.$http = $http;
    this.Analytics = Analytics;
  }

  _createClass(CheckoutService, [{
    key: "checkout",
    value: function checkout(paypal, returnUrl, cancelUrl, shippingId) {
      var _this = this;

      var url = localized.apiURL + '/cart/checkout';
      var params = {};

      if (typeof paypal !== 'undefined') {
        params.paypal = paypal;
        params.return_url = returnUrl;
        params.cancel_url = cancelUrl;
      }

      if (this.$cookies.get('vf.cart.partial') !== null) {
        try {
          params.items = JSON.parse(this.$cookies.get('vf.cart.partial'));
        } catch (e) {
          params.items = {};
        }
      }

      if (shippingId) {
        params.shipping_id = shippingId;
      }

      return this.$http.post(url, params).then(function (response) {
        _this.$cookies.put('vf.cart.partial', null, {
          samesite: 'none',
          secure: true,
          path: '/'
        });

        _this.Analytics.beginCheckout(response.data);

        return response;
      });
    }
  }, {
    key: "completeOrder",
    value: function completeOrder(params) {
      var _this2 = this;

      var url = localized.apiURL + '/cart/order/complete';
      return this.$http.post(url, params).then(function (response) {
        _this2.Analytics.purchase(response.data);

        return response;
      });
    }
  }, {
    key: "confirmOrder",
    value: function confirmOrder(checkoutInfo) {
      var url = localized.apiURL + '/cart/order/confirm';
      var params = {
        shipping_id: checkoutInfo.selected_shipping_profile.shipping_id,
        billing_id: checkoutInfo.selected_billing_profile.billing_id,
        order_id: checkoutInfo.order.order_id,
        shipping_method: checkoutInfo.selected_shipping_method,
        shipping_first_name: checkoutInfo.shipping_first_name,
        shipping_last_name: checkoutInfo.shipping_last_name,
        shipping_email: checkoutInfo.shipping_email,
        shipping_address1: checkoutInfo.shipping_address1,
        shipping_address2: checkoutInfo.shipping_address2,
        shipping_city: checkoutInfo.shipping_city,
        shipping_state: checkoutInfo.shipping_state,
        shipping_zip: checkoutInfo.shipping_zip,
        shipping_phone: checkoutInfo.shipping_phone,
        billing_first_name: checkoutInfo.billing_first_name,
        billing_last_name: checkoutInfo.billing_last_name,
        billing_email: checkoutInfo.billing_email,
        billing_address1: checkoutInfo.billing_address1,
        billing_address2: checkoutInfo.billing_address2,
        billing_city: checkoutInfo.billing_city,
        billing_state: checkoutInfo.billing_state,
        billing_zip: checkoutInfo.billing_zip,
        billing_phone: checkoutInfo.billing_phone,
        return_url: checkoutInfo.return_url
      };

      if (localized.settings.general.checkout.company_name_option) {
        params.organization = checkoutInfo.extraFields.organization;
      }

      if (localized.settings.general.checkout.purchase_order_option) {
        params.rr_po_num = checkoutInfo.extraFields.rr_po_num;
      }

      if (localized.settings.general.checkout.issuing_office_option) {
        params.issuing_office = checkoutInfo.extraFields.issuing_office;
      }

      if (localized.settings.general.checkout.cost_center_option) {
        params.cost_center_code = checkoutInfo.extraFields.cost_center_code;
      }

      if (localized.settings.general.checkout.attention_option) {
        params.attention = checkoutInfo.extraFields.attention;
      }

      if (localized.settings.general.checkout.notes_option) {
        params.notes = checkoutInfo.extraFields.notes;
      }

      if (checkoutInfo.extraFields.f1 !== '') {
        params.f1 = checkoutInfo.extraFields.f1;
      }

      if (checkoutInfo.extraFields.f2 !== '') {
        params.f2 = checkoutInfo.extraFields.f2;
      }

      if (checkoutInfo.extraFields.f3 !== '') {
        params.f3 = checkoutInfo.extraFields.f3;
      }

      if (checkoutInfo.extraFields.f4 !== '') {
        params.f4 = checkoutInfo.extraFields.f4;
      }

      if (checkoutInfo.extraFields.f5 !== '') {
        params.f5 = checkoutInfo.extraFields.f5;
      }

      if (checkoutInfo.extraFields.f6 !== '') {
        params.f6 = checkoutInfo.extraFields.f6;
      }

      return this.$http.post(url, params).then(function (response) {
        return response;
      });
    }
  }, {
    key: "getShippingMethods",
    value: function getShippingMethods(orderId, profileId, zipcode) {
      var url = localized.apiURL + '/cart/order/shipping/methods';
      var params = {
        order_id: orderId,
        shipping_id: profileId,
        zipcode: zipcode
      };
      return this.$http.post(url, params).then(function (response) {
        return response;
      });
    }
  }, {
    key: "priceAvailabilityResponse",
    value: function priceAvailabilityResponse(order, _priceAvailabilityResponse, reconfirm) {
      var url = localized.apiURL + '/cart/order/price-availability';
      var params = {
        order_id: order.order.order_id,
        return_url: order.return_url,
        price_availability_response: _priceAvailabilityResponse,
        reconfirm: reconfirm
      };
      return this.$http.post(url, params).then(function (response) {
        return response;
      });
    }
  }]);

  return CheckoutService;
}();

_defineProperty(CheckoutService, "$inject", ['$cookies', '$http', 'Analytics']);
;// CONCATENATED MODULE: ./assets/app/dev/public/services/debug.service.ts
function debugService() {
  var self = this;
  var debugMode = localized.settings.general.debug;

  self.log = function (lA, lB, lC, lD) {
    if (debugMode) {
      if (lA && lB && lC && lD) {
        // eslint-disable-next-line no-console
        console.log(lA, lB, lC, lD);
      } else if (lA && lB && lC) {
        // eslint-disable-next-line no-console
        console.log(lA, lB, lC);
      } else if (lA && lB) {
        // eslint-disable-next-line no-console
        console.log(lA, lB);
      } else if (lA) {
        // eslint-disable-next-line no-console
        console.log(lA);
      }
    }
  };

  this.warn = function (msg) {
    if (debugMode) {
      console.warn(msg);
    }
  };
}
;// CONCATENATED MODULE: ./assets/app/dev/public/services/favorites.service.ts
favoritesService.$inject = ['$http', '$q', 'Alerts', 'User'];
function favoritesService($http, $q, Alerts, User) {
  var self = this;
  /**
   * List of items.
   */

  self.items = {};
  /**
   * Add product to favorites.
   *
   * @param {number} productId
   */

  self.add = function (productId) {
    if (!User.isAuthed) {
      Alerts.error('You must login to add an item to favorites.');
      return $q.reject(false);
    }

    return $http.post(localized.apiURL + '/cart/favorites/add', {
      product_id: productId
    });
  };
  /**
   * Retrieve item details.
   *
   */


  self.fillDetails = function () {
    return $http.get(localized.apiURL + '/cart/favorites/view').then(function (resp) {
      if (resp.data.favorites && resp.data.favorites.length) {
        self.items = resp.data.favorites;
      }

      return resp;
    });
  };
  /**
   * Remove product from favorites.
   *
   * @param {number} productId
   */


  self.remove = function (productId) {
    if (!User.isAuthed) {
      return false;
    }

    return $http.post(localized.apiURL + '/cart/favorites/remove', {
      product_id: productId
    });
  };
}
;// CONCATENATED MODULE: ./assets/app/dev/public/services/group.service.ts
groupService.$inject = ['$http', 'Analytics'];
function groupService($http, Analytics) {
  var self = this;
  /**
   * Adds/Updates an item in a group pending order
   *
   * @param {number} order_id        - the pending order id
   * @param {string} sku             - sku of the item to add/update
   * @param {number} qty             - the quantity of item to add
   * @param {number} shipping_method - the id of the shipping method to use on order recalculation
   * @return {unresolved}
   */

  self.addItem = function (order_id, sku, qty, shipping_method) {
    var params = {
      order_id: order_id,
      sku: sku,
      qty: qty,
      shipping_method: shipping_method
    };
    return $http.post(localized.apiURL + '/group/pending-order/add-item', params);
  };
  /**
   * Get list of accounts in group.
   *
   * @return {unresolved}
   */


  self.listGroup = function () {
    var params = {};
    return $http.post(localized.apiURL + '/group/account/list', params);
  };
  /**
   * Change group permissions for an account.
   *
   * @param {number}  customer_id
   * @param {boolean} active
   * @param {number}  approver
   * @param {boolean} admin
   * @return {unresolved}
   */


  self.changeGroupPermissions = function (customer_id, active, approver, admin, requestor, pending_emails) {
    var params = {
      customer_id: customer_id,
      active: active,
      approver: approver,
      admin: admin,
      requestor: requestor,
      pending_emails: pending_emails
    };
    return $http.post(localized.apiURL + '/group/account/modify', params);
  };
  /**
   * List completed group orders.
   *
   * @param {Object} params
   * @return {Promise} response
   */


  this.listGroupOrders = function (params) {
    var url = "".concat(localized.apiURL, "/group/orders");
    return $http.get(url, {
      params: params,
      paramSerializer: '$httpParamSerializerJQLike'
    });
  };
  /**
   * View a completed group order.
   *
   * @param {number} order_id
   * @return {unresolved}
   */


  self.viewGroupOrder = function (order_id) {
    var params = {};

    if (typeof order_id !== 'undefined') {
      params.order_id = order_id;
    }

    return $http.post(localized.apiURL + '/group/order/view', params);
  };
  /**
   * List pending group orders.
   *
   * @param {Object} params
   * @return {Promise} response
   */


  this.listGroupPendingOrders = function (params) {
    var url = "".concat(localized.apiURL, "/group/pending-orders");
    return $http.get(url, {
      params: params,
      paramSerializer: '$httpParamSerializerJQLike'
    });
  };
  /**
   * View pending group order.
   *
   * @param {boolean} sortBy
   * @return {unresolved}
   */


  self.viewGroupPendingOrder = function (order_id) {
    var params = {};

    if (typeof order_id !== 'undefined') {
      params.order_id = order_id;
    }

    return $http.post(localized.apiURL + '/group/pending-order/view', params);
  };
  /**
   * Cancel pending group order.
   *
   * @param {number} order_id
   * @return {unresolved}
   */


  self.cancelGroupPendingOrder = function (order_id) {
    var params = {};

    if (typeof order_id !== 'undefined') {
      params.order_id = order_id;
    }

    return $http.post(localized.apiURL + '/group/pending-order/cancel', params);
  };
  /**
   * Confirm pending group order.
   *
   * @param {Object} checkout_info
   * @return {Object}
   */


  self.confirmGroupOrder = function (checkout_info) {
    var params = {};
    params.shipping_id = checkout_info.selected_shipping_profile.shipping_id;
    params.billing_id = checkout_info.selected_billing_profile.billing_id;
    params.order_id = checkout_info.order_id;
    params.shipping_method = checkout_info.selected_shipping_method;
    params.shipping_first_name = checkout_info.shipping_first_name;
    params.shipping_last_name = checkout_info.shipping_last_name;
    params.shipping_email = checkout_info.shipping_email;
    params.shipping_address1 = checkout_info.shipping_address1;
    params.shipping_address2 = checkout_info.shipping_address2;
    params.shipping_city = checkout_info.shipping_city;
    params.shipping_state = checkout_info.shipping_state;
    params.shipping_zip = checkout_info.shipping_zip;
    params.shipping_phone = checkout_info.shipping_phone;
    params.billing_first_name = checkout_info.billing_first_name;
    params.billing_last_name = checkout_info.billing_last_name;
    params.billing_email = checkout_info.billing_email;
    params.billing_address1 = checkout_info.billing_address1;
    params.billing_address2 = checkout_info.billing_address2;
    params.billing_city = checkout_info.billing_city;
    params.billing_state = checkout_info.billing_state;
    params.billing_zip = checkout_info.billing_zip;
    params.billing_phone = checkout_info.billing_phone; //TODO: add customFields to settings service

    if (localized.settings.general.checkout.company_name_option) {
      params.organization = checkout_info.order.organization;
    }

    if (localized.settings.general.checkout.purchase_order_option) {
      params.rr_po_num = checkout_info.order.rr_po_num;
    }

    if (localized.settings.general.checkout.issuing_office_option) {
      params.issuing_office = checkout_info.order.issuing_office;
    }

    if (localized.settings.general.checkout.cost_center_option) {
      params.cost_center_code = checkout_info.order.cost_center_code;
    }

    if (localized.settings.general.checkout.attention_option) {
      params.attention = checkout_info.order.attention;
    }

    if (localized.settings.general.checkout.notes_option) {
      params.notes = checkout_info.order.notes;
    }

    if (localized.settings.general.checkout.notes_option) {
      params.approver_notes = checkout_info.order.approver_notes;
    }

    if (checkout_info.order.customFields) {
      if (checkout_info.order.customFields.f1 !== '') {
        params.f1 = checkout_info.order.customFields.f1;
      }

      if (checkout_info.order.customFields.f2 !== '') {
        params.f2 = checkout_info.order.customFields.f2;
      }

      if (checkout_info.order.customFields.f3 !== '') {
        params.f3 = checkout_info.order.customFields.f3;
      }

      if (checkout_info.order.customFields.f4 !== '') {
        params.f4 = checkout_info.order.customFields.f4;
      }

      if (checkout_info.order.customFields.f5 !== '') {
        params.f5 = checkout_info.order.customFields.f5;
      }

      if (checkout_info.order.customFields.f6 !== '') {
        params.f6 = checkout_info.order.customFields.f6;
      }
    }

    return $http.post(localized.apiURL + '/group/pending-order/confirm', params).then(function (resp) {
      return resp;
    });
  };
  /**
   * Complete pending group order.
   *
   * @param {Object} params
   * @return {Object}
   */


  self.completeGroupOrder = function (params) {
    return $http.post(localized.apiURL + '/group/pending-order/complete', params).then(function (resp) {
      Analytics.purchase(resp.data);
      return resp;
    });
  };
  /**
   * Remove item from a pending group order.
   *
   * @param {number} orderId
   * @param {number} productId
   * @return {Object}
   */


  this.groupPendingOrderRemoveItem = function (orderId, productId) {
    if (orderId) {
      var url = "".concat(localized.apiURL, "/group/pending-order/remove-item");
      var data = {
        order_id: orderId,
        product_id: productId
      };
      return $http.post(url, data);
    }
  };
  /**
   * Add RMA to a group order.
   *
   * @param {number} purch_id
   * @param {string} notes
   * @param {string} reason
   * @param {number} qty
   * @return {unresolved}
   */


  self.addGroupRma = function (purch_id, notes, reason, qty) {
    var params = {};
    params.purch_id = purch_id;
    params.notes = notes;
    params.reason = reason;
    params.qty = qty;
    return $http.post(localized.apiURL + '/group/rma/request', params);
  };
}
;// CONCATENATED MODULE: ./assets/app/dev/public/services/localized.service.ts
function localizedService() {
  var self = this;
  self.debugMode = localized.settings.general.debug;
  self.root = {
    url: localized.dir.url,
    path: localized.dir.root
  };
  self.apiURL = localized.apiURL;
  self.api_key = localized.settings.general.api_key;
  self.wpRestUrl = localized.dir.wpRestUrl + 'vendorfuel';
  self.wpNonce = localized.nonce;
  self.plugin_data = localized.plugin_data;
  self.branding = localized.branding;
  self.settings = localized.settings;
  self.pages = localized.pages;
  self.notifications = [];

  self.ClearNotifications = function () {
    self.notifications.splice(0, self.notifications.length);
  };

  self.PushNotification = function (notification) {
    var msg = notification.message;

    if (msg && typeof msg !== 'undefined' && msg !== null && msg !== '' && msg !== 'OK') {
      self.notifications.push(notification);
    }
  };

  self.GetNotifications = function () {
    return self.notifications;
  };

  self.RemoveNotification = function (index) {
    if (typeof self.notifications[index] !== 'undefined') {
      self.notifications.splice(index, 1);
    } else {
      self.notifications.push({
        type: 'danger',
        message: 'Whoops! Unable to remove notification.'
      });
    }
  };

  self.responseMessages = [];

  self.ClearResponseMsg = function () {
    self.responseMessages.splice(0, self.responseMessages.length);
  };

  self.PushResponseMsg = function (notification) {
    var msg = notification.message;

    if (msg && typeof msg !== 'undefined' && msg !== null && msg !== '' && msg !== 'OK') {
      self.responseMessages.push(notification);
    }
  };

  self.GetResponseMsgs = function () {
    return self.responseMessages;
  };

  self.RemoveResponseMsg = function (index) {
    if (typeof self.responseMessages[index] !== 'undefined') {
      self.responseMessages.splice(index, 1);
    } else {
      self.responseMessages.push({
        type: 'danger',
        message: 'Whoops! Unable to remove notification.'
      });
    }
  };

  self.RemoveAllNoticfitcations = function () {
    if (typeof self.responseMessage !== 'undefined') {
      self.responseMessages = [];
    } else {
      self.responseMessages.push({
        type: 'danger',
        message: 'Whoops! Unable to remove notifications.'
      });
    }
  };
}
;// CONCATENATED MODULE: ./assets/app/dev/public/services/punchout.service.ts

punchoutService.$inject = ['$http', 'Debug'];
function punchoutService($http, Debug) {
  var self = this;
  /**
   * List available punchout partners.
   *
   * @return {unresolved}
   */

  self.listPuchoutPartners = function () {
    var params = {};
    return $http.post(localized.apiURL + '/punchout/partner-catalog/list', params);
  };

  this.listSuppliers = function (customerId) {
    var params = {};

    if (customerId) {
      params.customer_id = customerId;
    }

    return $http.get(formatURLParams(localized.apiURL + '/punchout/suppliers', params));
  };

  this.supplierRequest = function (supplierId, returnUrl, orderId) {
    var data = {
      partner_id: supplierId,
      order_id: orderId,
      return_url: returnUrl
    };
    Debug.log(data);
    var url = "".concat(localized.apiURL, "/punchout/suppliers/").concat(supplierId, "/request");
    return $http.post(url, data).then(function (response) {
      if (response.data.start_page_url) {
        window.location.href = response.data.start_page_url;
      } else {
        return response;
      }
    });
  };

  self.supplierReturn = function (returned_cxml, order_id) {
    var params = {};
    params.cxml = returned_cxml;
    params.order_id = order_id;
    return $http.post(localized.apiURL + '/punchout/return', params);
  };
  /**
   * Submit a punchout request to specified partner.
   *
   * @param {number} partner_id
   * @param {string} return_url
   * @param {number} order_id
   * @return {unresolved}
   */


  self.punchoutRequest = function (partner_id, return_url, order_id) {
    var params = {};
    params.partner_id = partner_id;
    params.order_id = order_id;
    params.return_url = return_url;
    Debug.log(params);
    return $http.post(localized.apiURL + '/punchout/partner-catalog/request', params);
  };
  /**
   * Return from punchout sessions with cxml for a specific order.
   *
   * @param {Object} returned_cxml
   * @param {number} order_id
   * @return {unresolved}
   */


  self.punchoutReturn = function (returned_cxml, order_id) {
    var params = {};
    params.cxml = returned_cxml;
    params.order_id = order_id;
    return $http.post(localized.apiURL + '/punchout/partner-catalog/return', params);
  };
}
;// CONCATENATED MODULE: ./assets/app/dev/public/common/get-bool.ts
function getBool(val) {
  switch (val) {
    case 'true':
    case '1':
    case 1:
      return true;

    default:
      return false;
  }
}
;// CONCATENATED MODULE: ./assets/app/dev/public/services/user.service.ts



userService.$inject = ['$cookies', '$http', '$injector', 'Auth', 'Alerts', 'Analytics', 'Debug', 'Utils'];
function userService($cookies, $http, $injector, Auth, Alerts, Analytics, Debug, Utils) {
  /**
   * User variables.
   */
  var self = this;
  self.name = $cookies.get('vf.user.name');
  self.email = $cookies.get('vf.user.email');

  try {
    self.group = JSON.parse($cookies.get('vf.user.group'));
  } catch (e) {
    self.group = '';
  }

  self.group_admin = getBool($cookies.get('vf.user.group_admin'));
  self.approver = getBool($cookies.get('vf.user.approver'));
  self.remember = getBool($cookies.get('vf.user.remember'));
  self.last_login = $cookies.get('vf.user.last_login');
  self.isAuthed = Auth.isAuthed();
  self.isGuest = getBool($cookies.get('vf.user.is-guest'));
  self.attemptedPage = $cookies.get('vf.user.attempted-page');
  self.cart_count = getIntFromCookie($cookies.get('vf.cart.cartCount'));
  self.punchoutOnly = getBool($cookies.get('vf.user.punchoutOnly'));
  self.mixedPunchout = getBool($cookies.get('vf.user.mixedPunchout'));
  self.company = $cookies.get('vf.user.company');
  self.defaultShippingProfile = getIntFromCookie($cookies.get('vf.user.defaultShippingProfile'));
  self.defaultBillingProfile = getIntFromCookie($cookies.get('vf.user.defaultBillingProfile'));
  self.group_id = getIntFromCookie($cookies.get('vf.user.group_id'));
  self.group_parent_id = getIntFromCookie($cookies.get('vf.user.group_parent_id'));
  self.price_availability = getBool($cookies.get('vf.user.price_availability'));
  self.cost_center_is_required = getBool($cookies.get('vf.user.cost_center_is_required'));
  self.currentGroup_id = getIntFromCookie($cookies.get('vf.user.currentGroup_id'));

  var update = function update(info) {
    self.name = info.name;
    self.email = info.email;
    self.company = info.company;
    self.group_admin = info.group_admin;
    self.approver = info.approver;
    self.isGuest = info.guest;
    self.group = info.group;
    self.last_login = info.last_login;
    self.punchoutOnly = info.punchout_only;
    self.mixedPunchout = info.mixed_punchout;
    self.defaultShippingProfile = info.default_shipping_profile;
    self.defaultBillingProfile = info.default_billing_profile;
    self.group_id = info.group_id;
    self.group_parent_id = info.group_parent_id;
    self.price_availability = info.price_availability;
    self.cost_center_is_required = info.cost_center_is_required;
    self.currentGroup_id = info.group_id;
    var cookieOptions = {
      samesite: 'none',
      secure: true,
      path: '/'
    };

    if (self.remember) {
      var currentTime = new Date();
      currentTime.setDate(currentTime.getDate() + 14);
      cookieOptions = {
        samesite: 'none',
        secure: true,
        path: '/',
        expires: currentTime
      };
    }

    $cookies.put('vf.user.name', self.name, cookieOptions);
    $cookies.put('vf.user.email', self.email, cookieOptions);
    $cookies.put('vf.user.group_admin', self.group_admin, cookieOptions);
    $cookies.put('vf.user.approver', self.approver, cookieOptions);

    try {
      $cookies.put('vf.user.group', JSON.stringify(self.group), cookieOptions);
    } catch (e) {
      $cookies.put('vf.user.group', '', cookieOptions);
    }

    $cookies.put('vf.user.remember', self.remember, cookieOptions);
    $cookies.put('vf.user.last_login', self.last_login, cookieOptions);
    $cookies.put('vf.cart.cartCount', self.cart_count, cookieOptions);
    $cookies.put('vf.user.punchoutOnly', self.punchoutOnly, cookieOptions);
    $cookies.put('vf.user.mixedPunchout', self.mixedPunchout, cookieOptions);
    $cookies.put('vf.user.company', self.company, cookieOptions);
    $cookies.put('vf.user.defaultShippingProfile', self.defaultShippingProfile, cookieOptions);
    $cookies.put('vf.user.defaultBillingProfile', self.defaultBillingProfile, cookieOptions);
    $cookies.put('vf.user.group_id', self.group_id, cookieOptions);
    $cookies.put('vf.user.group_parent_id', self.group_parent_id, cookieOptions);
    $cookies.put('vf.user.price_availability', self.price_availability, cookieOptions);
    $cookies.put('vf.user.cost_center_is_required', self.cost_center_is_required, cookieOptions);
    $cookies.put('vf.user.currentGroup_id', self.currentGroup_id, cookieOptions);
    $cookies.put('vf.user.is-guest', self.isGuest, {
      samesite: 'none',
      secure: true,
      path: '/'
    }); //update cart service with details from login

    $injector.get('Cart').updateFromApi(info);
    Debug.log(this);
  };

  var success = function success(resp) {
    if (!resp.data.errors.length) {
      Auth.saveToken(resp.data.token, self.remember);
      update(resp.data);
      self.isAuthed = true;
    }

    return resp;
  };

  var clear = function clear() {
    Auth.clearToken();
    self.isAuthed = false;
    self.isGuest = false;
    self.name = null;
    self.email = null;
    self.company = null;
    self.group_admin = null;
    self.approver = null;
    self.group = null;
    self.last_login = null;
    self.punchoutOnly = null;
    self.mixedPunchout = null;
    self.defaultShippingProfile = 0;
    self.defaultBillingProfile = 0;
    self.group_id = null;
    self.group_parent_id = null;
    self.price_availability = null;
    self.cost_center_is_required = null;
    self.currentGroup_id = null;
  };
  /**
   * Update a users group.
   *
   * @param {number} groupId
   */


  self.updateGroup = function (groupId) {
    self.currentGroup_id = groupId;
    $cookies.put('vf.user.currentGroup_id', self.currentGroup_id, {
      samesite: 'none',
      secure: true,
      path: '/'
    });
  };
  /**
   * Register a new user.
   *
   * @param {Object} userData
   */


  self.register = function (userData) {
    var token = Auth.getToken();
    userData['prev-token'] = token;
    return $http.post(localized.apiURL + '/account/register', userData).then(function (resp) {
      Analytics.signUp();
      return success(resp);
    });
  };
  /**
   * User login.
   *
   * @param {Object} userData
   */


  self.login = function (userData) {
    var token = Auth.getToken();
    clear();
    self.remember = userData.remember && true || false;
    return $http.post(localized.apiURL + '/account/login', {
      email: userData.email,
      password: userData.password,
      'prev-token': token
    }).then(function (resp) {
      if (!resp.data.errors.length) {
        Analytics.login();
      }

      return success(resp);
    });
  };
  /**
   * User logout.
   *
   * @return {Object} Response
   */


  this.logout = function () {
    var url = "".concat(localized.apiURL, "/account/logout");
    var data = {};
    return $http.post(url, data).then(function (response) {
      clear();
      return response;
    });
  };
  /**
   * Guest login.
   *
   * @return {Object}
   */


  self.guestLogin = function () {
    clear();
    return $http.post(localized.apiURL + '/account/guest-login', {}).then(function (resp) {
      self.name = 'Guest';
      self.remember = false;
      Auth.saveToken(resp.data.token);
      self.isAuthed = true;
      $cookies.put('vf.user.name', self.name, {
        samesite: 'none',
        secure: true,
        path: '/'
      });
      $cookies.put('vf.user.is-guest', true, {
        samesite: 'none',
        secure: true,
        path: '/'
      });
      $cookies.put('vf.user.remember', self.remember, {
        samesite: 'none',
        secure: true,
        path: '/'
      });
      self.isGuest = true;
      Debug.log(self);
      return resp;
    });
  };
  /**
   * Redirect to login page if a protected page has been loaded. Redirect user to requested page on login.
   *
   * @param {boolean} showModal
   */


  self.redirectToLogin = function (showModal) {
    self.attemptedPage = window.location.href;
    $cookies.get('vf.user.attempted-page', self.attemptedPage);

    if (showModal && angular.element('#errorModal').length) {
      Alerts.modal({
        enabled: true,
        redirectUrl: Utils.getPageUrl('login'),
        title: 'Error'
      });
      Alerts.error('This action requires authentication');
    } else {
      window.location.href = localized.pages.login.url;
    }
  };
  /**
   * Redirect user to attempted page after succesfull login.
   *
   */


  self.redirectToAttempted = function () {
    $cookies.remove('vf.user.attempted-page', {
      samesite: 'none',
      secure: true,
      path: '/'
    });

    if (!self.attemptedPage || window.location.href === self.attemptedPage) {
      window.location.reload();
    } else {
      window.location.href = self.attemptedPage;
    }
  };
  /**
   * Get general settings.
   *
   * @return {Object}
   */


  self.fillInfo = function () {
    return $http.get(localized.apiURL + '/account/info/view').then(function (resp) {
      update(resp.data.info);
      return resp;
    });
  };
  /**
   * Get user account info.
   *
   * @return {Object}
   */


  self.loadCustomer = function () {
    return $http.get(localized.apiURL + '/account/load').then(function (resp) {
      update(resp.data);
      return resp;
    });
  };
  /**
   * Update user account.
   *
   * @param {Object} userData
   * @return {Object}
   */


  self.updateInfo = function (userData) {
    return $http.post(localized.apiURL + '/account/info/modify', userData).then(function (resp) {
      if (!resp.data.errors.length) {
        update(resp.data);
      }

      return resp;
    });
  };
  /**
   * Get customer roles for registration
   *
   * @return {Object} - All roles and documents
   */


  self.roles = function () {
    return $http.get(formatURLParams(localized.apiURL + '/roles', {})).then(function (resp) {
      return resp;
    });
  };
  /**
   * Get customer roles for registration
   *
   * @param {number} id - The Role to retrieve
   * @return {Object} - Role settings
   */


  self.role = function (id) {
    return $http.get(formatURLParams(localized.apiURL + '/roles/' + id, {})).then(function (resp) {
      return resp;
    });
  };
  /**
   * Get address profiles.
   *
   * @param {number} order_id
   * @return {unresolved}
   */


  self.getProfiles = function (order_id) {
    var params = {};

    if (typeof order_id !== 'undefined') {
      params.order_id = order_id;
    }

    return $http.post(localized.apiURL + '/account/address/list', params).then(function (resp) {
      return resp;
    });
  };
  /**
   * Save a shipping address profile.
   *
   * @param {Object} profileForm
   * @return {Object}
   */


  self.addShippingProfile = function (profileForm) {
    var params = {
      type: 'shipping'
    };
    angular.forEach(profileForm, function (value, key) {
      params[key] = value;
    });
    return $http.post(localized.apiURL + '/account/address/modify', params).then(function (resp) {
      return resp;
    });
  };
  /**
   * Remove a shipping address profile.
   *
   * @param {number} profileID
   * @return {Object}
   */


  self.removeShippingProfile = function (profileID) {
    return $http.post(localized.apiURL + '/account/address/remove', {
      type: 'shipping',
      shipping_id: profileID
    }).then(function (resp) {
      return resp;
    });
  };
  /**
   * Save a billing address profile.
   *
   * @param {Object} profileForm
   * @return {Object}
   */


  self.addBillingProfile = function (profileForm) {
    var params = {
      type: 'billing'
    };
    angular.forEach(profileForm, function (value, key) {
      params[key] = value;
    });
    return $http.post(localized.apiURL + '/account/address/modify', params).then(function (resp) {
      return resp;
    });
  };
  /**
   * Remove a billing address profile.
   *
   * @param {number} profileID
   * @return {Object}
   */


  self.removeBillingProfile = function (profileID) {
    return $http.post(localized.apiURL + '/account/address/remove', {
      type: 'billing',
      billing_id: profileID
    }).then(function (resp) {
      return resp;
    });
  };
  /**
   * Set a default shipping or billing address profile.
   *
   * @param {number} profileID
   * @param {string} type
   * @return {Object}
   */


  self.setDefaultProfile = function (profileID, type) {
    return $http.post(localized.apiURL + '/account/address/default', {
      type: type,
      id: profileID
    }).then(function (resp) {
      update(resp.data);
      return resp;
    });
  };
  /**
   * List completed orders for the current user.
   *
   * @param {Object} params
   */


  this.listOrders = function (params) {
    var url = "".concat(localized.apiURL, "/account/orders");
    return $http.get(url, {
      params: params,
      paramSerializer: '$httpParamSerializerJQLike'
    });
  };
  /**
   * View completed order.
   *
   * @param {boolean} sortBy
   * @return {unresolved}
   */


  self.viewOrder = function (order_id) {
    var params = {};

    if (typeof order_id !== 'undefined') {
      params.order_id = order_id;
    }

    return $http.post(localized.apiURL + '/account/order/view', params);
  };
  /**
   * Checkout STUB.
   */


  self.checkout = function () {
    Debug.log('checkout function here');
  };
  /**
   * Add RMA to an order.
   *
   * @param {number} purchId
   * @param {string} notes
   * @param {string} reason
   * @param {number} qty
   */


  this.addRma = function (purchId, notes, reason, qty) {
    var url = "".concat(localized.apiURL, "/account/rma/request");
    var params = {
      purch_id: purchId,
      notes: notes,
      reason: reason,
      qty: qty
    };
    return $http.post(url, params);
  };
  /**
   * Request a password reset.
   *
   * @param {string} email
   * @param {string} url
   * @return {unresolved}
   */


  self.requestPasswordReset = function (email, url) {
    var params = {
      email: email,
      url: url
    };
    return $http.post(localized.apiURL + '/account/password-reset/request', params);
  };
  /**
   * Validate password reset.
   *
   * @param {string}  code
   * @param {boolean} auth
   * @return {unresolved}
   */


  self.validatePasswordReset = function (code, auth) {
    var params = {
      code: code,
      auth: auth
    };
    return $http.post(localized.apiURL + '/account/password-reset/validate', params);
  };
  /**
   * Reset password.
   *
   * @param {string}  code
   * @param {boolean} auth
   * @param {string}  question
   * @param {string}  answer
   * @param {string}  pass
   * @param {boolean} verify
   * @return {unresolved}
   */


  self.resetPassword = function (code, auth, question, answer, pass, verify) {
    var params = {
      code: code,
      auth: auth
    };

    if (typeof question !== 'undefined') {
      params.security_qa_id = question;
    }

    if (answer !== '') {
      params.security_answer = answer;
    }

    params.password = pass;
    params.retype_password = verify;
    return $http.post(localized.apiURL + '/account/password-reset/submit', params);
  };
  /**
   * Forced password reset.
   *
   * @param {string} password
   * @return {unresolved}
   */


  this.forcedResetPassword = function (password) {
    var url = "".concat(localized.apiURL, "/account/info/modify");
    var params = {
      password: password,
      password_confirmation: password,
      name: self.name,
      email: self.email
    };
    return $http.post(url, params);
  };
  /**
   * Get banner for specified area.
   *
   * @param {string} area
   * @return {unresolved}
   */


  self.getBanner = function (area) {
    var params = {
      area: area
    };
    return $http.post(localized.apiURL + '/catalog/banner/view', params);
  };

  self.sendOrderEmail = function (order_id) {
    var params = {
      order_id: order_id
    };
    return $http.post(localized.apiURL + '/account/order/resend-email', params);
  };

  this.resendVerificationEmail = function (email, returnUrl) {
    var data = {
      email: email,
      verification_return_url: returnUrl
    };
    var url = "".concat(localized.apiURL, "/account/email/link");
    return $http.post(url, data);
  };

  this.verifyEmail = function (auth, code) {
    var data = {
      auth: auth,
      code: code
    };
    var url = "".concat(localized.apiURL, "/account/email/verify");
    return $http.post(url, data);
  };
}
;// CONCATENATED MODULE: ./assets/app/dev/public/services/utils.service.ts
utilsService.$inject = ['Debug'];
function utilsService(Debug) {
  var self = this;
  var parser = document.createElement('a');
  parser.href = window.location.href;
  parser._params = {};
  parser._pathPieces = parser.pathname.replace(/^\/+|\/+$/g, '').split('/');
  var paramString = parser.search;

  if (paramString.charAt(0) === '?') {
    var hashes = paramString.slice(1).split('&');

    for (var i = 0; i < hashes.length; i++) {
      var hash = hashes[i].split('=');
      parser._params[hash[0]] = hash[1];
    }
  }
  /**
   * Parses params from key.
   *
   * @param {string} key
   * @return {string}
   */


  parser.param = function (key) {
    return parser._params[key];
  };
  /**
   * Parses path pieces from index.
   *
   * @param {number} index
   * @return {Array}
   */


  parser.pathPiece = function (index) {
    return parser._pathPieces[index];
  };

  self.urlParser = parser;
  /**
   * Navigate to specified page with the attached params.
   *
   * @param {string} page
   * @param {Object} params
   */

  self.goToPage = function (page) {
    window.location.href = page;
  };

  this.getPageUrl = function (pageKey, params) {
    Debug.log("Getting page URL for \"".concat(pageKey, "\"."));

    if (localized.pages[pageKey]) {
      var page = localized.pages[pageKey];
      var url = page.url;

      if (!angular.isUndefined(params) && angular.isObject(params)) {
        url += '?';
        angular.forEach(params, function (val, key) {
          url += encodeURIComponent(key) + '=' + encodeURIComponent(val);
        });
      }

      return url;
    }

    Debug.warn("Unable to find mapped page with key \"".concat(pageKey, "\"."));
    return "".concat(location.origin, "/").concat(pageKey);
  };
}
;// CONCATENATED MODULE: ./assets/app/dev/public/factories/collections.factory.ts
CollectionsFactory.$inject = ['$http', 'Analytics'];
function CollectionsFactory($http, Analytics) {
  var self = this;
  self.selectedCollection = {};

  try {
    self.selectedCollection = JSON.parse(localStorage.getItem('selectedCollection'));
  } catch (e) {
    self.selectedCollection = {};
  }

  self.list = function (params) {
    Analytics.search(params.q);
    return $http.post(localized.apiURL + '/catalog/search/new', params).then(function (resp) {
      Analytics.viewSearchResults(params.q, resp.data.product_briefs);
      return resp;
    });
  };

  self.getCollections = function () {
    var req = {
      url: localized.apiURL + '/catalog/collection/',
      method: 'GET'
    };
    return $http(req).then(function (resp) {
      return resp.data;
    });
  };

  self.viewCollection = function (params) {
    var req = {
      url: localized.apiURL + '/catalog/collection/' + params.col_id,
      method: 'GET',
      params: params
    };
    return $http(req).then(function (resp) {
      return resp.data;
    });
  };

  self.goToCollection = function (id) {
    self.viewCollection(id).then(function (resp) {
      localStorage.setItem('selectedCollection', JSON.stringify(resp.collection));
    })["finally"](function () {
      var page = localized.pages.collection;

      if (angular.isUndefined(page)) {
        throw new Error('Unable to find that page.');
      } else {
        window.location.href = page.url;
      }
    });
  };

  return self;
}
;// CONCATENATED MODULE: ./assets/app/dev/public/factories/interceptor.factory.ts

interceptorFactory.$inject = ['$cookies', '$q', 'Alerts', 'Auth', 'Debug', 'Utils'];
function interceptorFactory($cookies, $q, Alerts, Auth, Debug, Utils) {
  var version = 2;

  var configDataAppend = function configDataAppend(data, key, value) {
    if (typeof data === 'undefined') {
      data = {};
    }

    if (data instanceof FormData) {
      data.append(key, value);
    } else {
      data[key] = value;
    }

    return data;
  };

  var forcePasswordChange = function forcePasswordChange() {
    var url = "".concat(Utils.getPageUrl('login'));

    if (!location.href.includes(url)) {
      location.assign("".concat(url, "?change_pw&redirect_to=").concat(location.pathname).concat(location.search));
    }
  };

  return {
    request: function request(config) {
      if (config.url.indexOf(localized.apiURL) !== 0 || config.skipAuth) {
        return config;
      }

      config = configDataAppend(config, 'requestTimestamp', new Date().getTime() / 1000);
      var groupId = getIntFromCookie($cookies.get('vf.user.group_id'));
      var currentGroupId = getIntFromCookie($cookies.get('vf.user.currentGroup_id'));

      if (groupId && groupId !== currentGroupId) {
        config.data = configDataAppend(config.data, 'use_group', currentGroupId);
        config.params = configDataAppend(config.params, 'use_group', currentGroupId);
      }

      config.params = configDataAppend(config.params, 'apikey', localized.settings.general.api_key);
      config.data = configDataAppend(config.data, 'time', config.requestTimestamp);
      config.data = configDataAppend(config.data, 'device', 'website' + version);
      var token = Auth.getToken();

      if (token) {
        config.headers = configDataAppend(config.headers, 'Authorization', 'Bearer ' + token);
        config.data = configDataAppend(config.data, 'auth-token', token);
      }

      var tokena = Auth.getAdminTokenA();
      var tokenb = Auth.getAdminTokenB();
      var adminJwt = Auth.getAdminJWT();

      if (tokena && tokenb || adminJwt) {
        config.data = configDataAppend(config.data, 'tokena', tokena);
        config.data = configDataAppend(config.data, 'tokenb', tokenb);
        config.data = configDataAppend(config.data, 'token', adminJwt);
      }

      if (config.data instanceof FormData) {
        config.transformRequest = angular.identity;
        delete config.headers['Content-Type'];
      }

      config.headers['x-requested-with'] = 'XMLHttpRequest';
      config.withCredentials = true;
      Debug.log('request:', config);
      return config;
    },
    response: function response(resp) {
      Debug.log('response:', resp);

      if (resp.data.change_pw) {
        forcePasswordChange();
      }

      if (resp.config.url.indexOf(localized.apiURL) !== 0) {
        return resp;
      }

      if (resp.data.notifications && resp.data.notifications.length) {
        angular.forEach(resp.data.notifications, function (msg) {
          Alerts.message(msg);
        });
      }

      if (resp.data.warnings && resp.data.warnings.length) {
        angular.forEach(resp.data.warnings, function (msg) {
          Alerts.warning(msg);
        });
      }

      if (resp.data.errors && resp.data.errors.length) {
        console.error(resp.data.errors);
        angular.forEach(resp.data.errors, function (err) {
          Alerts.error(err);

          switch (err) {
            case 'E0001':
              Auth.clearToken();
              window.location.assign('/login');
              break;

            case 'E0002':
              break;

            default:
              return $q.reject(resp);
          }
        });
      }

      var token = resp.headers('X-Auth-Token');

      if (token) {
        Auth.saveToken(token);
      }

      return resp;
    },
    responseError: function responseError(errResp) {
      console.error(errResp); //if (errResp.status === 401) {
      // TODO: handle authentication error code - redirect to login
      // User.redirectToLogin(true); // cyclic dependency - how to do this...
      //}

      return $q.reject(errResp);
    }
  };
}
;// CONCATENATED MODULE: ./assets/app/dev/public/factories/products.factory.ts
productsFactory.$inject = ['$http', '$resource', 'Analytics'];
function productsFactory($http, $resource, Analytics) {
  var self = this;
  self.recentlyViewed = JSON.parse(localStorage.getItem('recentlyViewed') || '[]'); // TODO: Build out functionality for products
  // TODO: Set exposed methods so that can use resource or not.

  var resource = $resource(localized.apiURL + '/catalog/product/:verb', {}, {
    view: {
      method: 'POST',
      params: {
        verb: 'view'
      }
    },
    reviews: {
      method: 'POST',
      params: {
        verb: 'reviews'
      }
    }
  });
  self.get = resource.view;
  /**
   * List products.
   *
   * @param {Object} params
   */

  self.list = function (params) {
    Analytics.search(params.q);
    return $http.post(localized.apiURL + '/catalog/search/new', params).then(function (resp) {
      Analytics.viewSearchResults(params.q, resp.data.product_briefs);
      return resp;
    });
  };
  /**
   * List more products.
   *
   * @param {Object} params
   */


  self.listMore = function (productBriefs) {
    var params = {
      products: productBriefs
    };
    return $http.post(localized.apiURL + '/catalog/product/briefs', params);
  };
  /**
   * Add product review.
   *
   * @param {number} productId
   * @param {Object} reviewForm
   */


  self.addReview = function (productId, reviewForm) {
    var params = {
      product_id: productId
    };
    angular.forEach(reviewForm, function (value, key) {
      params[key] = value;
    });
    return $http.post(localized.apiURL + '/account/product-review/modify', params).then(function (resp) {
      return resp;
    });
  };
  /**
   * Flag reviews as helpful or not.
   *
   * @param {number}  productId
   * @param {number}  reviewId
   * @param {boolean} isHelpful
   * @return {Object}
   */


  self.helpfulRating = function (productId, reviewId, isHelpful) {
    var params = {
      product_id: productId,
      review_id: reviewId,
      helpful: isHelpful
    };
    return $http.post(localized.apiURL + '/account/product-review/rate', params).then(function (resp) {
      self.reviews = resource.reviews;
      return resp;
    });
  };

  self.appendRecent = function (product) {
    var viewed = false;
    angular.forEach(self.recentlyViewed, function (value) {
      if (value.product_id === product.product_id) {
        viewed = true;
      }
    });

    if (!viewed) {
      if (self.recentlyViewed.length < 12) {
        self.recentlyViewed.push(product);
      } else if (self.recentlyViewed.length === 12) {
        self.recentlyViewed.shift();
        self.recentlyViewed.push(product);
      }

      localStorage.setItem('recentlyViewed', JSON.stringify(self.recentlyViewed));
    }
  };

  self.categories = function (id) {
    var params = {
      id: id
    };
    return $http({
      url: localized.apiURL + '/catalog/category/list',
      method: 'POST',
      params: params
    }).then(function (resp) {
      return resp.data;
    });
  };

  self.viewCategory = function (catId, searchParams) {
    var req = {
      url: localized.apiURL + '/catalog/category/' + catId,
      method: 'GET',
      params: searchParams
    };
    return $http(req).then(function (resp) {
      return resp.data;
    });
  };

  self.reviews = resource.reviews;
  return this;
}
;// CONCATENATED MODULE: ./assets/app/dev/public/filters/tel.filter.ts
function telFilter() {
  return function (tel) {
    if (!tel) {
      return '';
    }

    var value = tel.toString().trim().replace(/^\+/, '');

    if (value.match(/[^0-9]/)) {
      return tel;
    }

    var city, number;

    switch (value.length) {
      case 1:
      case 2:
      case 3:
        city = value;
        break;

      default:
        city = value.slice(0, 3);
        number = value.slice(3);
    }

    if (number) {
      if (number.length > 3) {
        number = number.slice(0, 3) + '-' + number.slice(3, 7);
      }

      return ('(' + city + ') ' + number).trim();
    }

    return '(' + city;
  };
}
;// CONCATENATED MODULE: ./assets/app/dev/public/public.module.ts
















var PublicModule = angular.module('vfApp', ['ngResource', 'LocalStorageModule', 'ngCookies', 'ngSanitize', 'ui.mask']).config(['$httpProvider', 'localStorageServiceProvider', '$sceProvider', '$locationProvider', 'uiMask.ConfigProvider', function ($httpProvider, localStorageServiceProvider, $sceProvider, $locationProvider, uiMaskConfigProvider) {
  $httpProvider.interceptors.push('vfInterceptor');
  localStorageServiceProvider.setPrefix('vf').setStorageCookie(0, '/', false).setStorageType('sessionStorage');
  $sceProvider.enabled(false);
  $locationProvider.html5Mode({
    enabled: true,
    requireBase: false,
    rewriteLinks: false
  });
  uiMaskConfigProvider.maskDefinitions({
    2: /[2-9]/,
    9: /\d/,
    A: /[a-zA-Z]/,
    '*': /[a-zA-Z0-9]/
  });
}]).service('Alerts', alertsService).service('Analytics', analyticsService).service('Auth', authService).service('Cart', cartService).service('Checkout', CheckoutService).service('Debug', debugService).service('Favorites', favoritesService).service('Group', groupService).service('Localized', localizedService).service('Punchout', punchoutService).service('User', userService).service('Utils', utilsService).factory('Collections', CollectionsFactory).factory('vfInterceptor', interceptorFactory).factory('Products', productsFactory).filter('tel', telFilter).name;
;// CONCATENATED MODULE: ./assets/app/dev/public/index.ts

document.addEventListener('DOMContentLoaded', function () {
  angular.bootstrap(document, ['vfApp']);
});
/******/ })()
;