<?php
class Vendorfuel_Enqueue {

	public function __construct() {
		$this->general_settings = get_option( 'vendorfuel-general-settings' );
		if ( is_admin() ) {
			$this->plugin_data = get_plugin_data( VENDORFUEL_ROOT_DIR . '/vendorfuel.php' );
		}
		$this->required_scripts();
	}

	/**
	 * ANGULAR APP AND DEPENDENCIES - CONCATENATE AND MINIFY FOR PROODUCTION
	 **/
	private function required_scripts() {
		wp_enqueue_script( 
			'angular',
			'//ajax.googleapis.com/ajax/libs/angularjs/1.8.2/angular.min.js', 
			array( 'jquery' ), 
			'1.8.2' 
		);

		wp_enqueue_script( 
			'angular-resource', 
			'//code.angularjs.org/1.8.2/angular-resource.min.js', 
			array( 'angular' ),
			'1.8.2'
		);

		wp_enqueue_script( 
			'angular-sanitize', 
			'//code.angularjs.org/1.8.2/angular-sanitize.min.js', 
			array( 'angular' ), 
			'1.8.2'
		);

		wp_enqueue_script( 
			'angular-cookies', 
			'//code.angularjs.org/1.8.2/angular-cookies.min.js', 
			array( 'angular' ),
			'1.8.2' 
		);

		wp_enqueue_script( 
			'angular-local-storage', 
			'//cdnjs.cloudflare.com/ajax/libs/angular-local-storage/0.7.1/angular-local-storage.min.js', 
			array( 'angular' ),
			'0.7.1'
		);

		wp_enqueue_style(
			'bootstrap-icons',
			'//cdn.jsdelivr.net/npm/bootstrap-icons@1.8.1/font/bootstrap-icons.css', 
			array(), 
			'1.8.1', 
		);
	}

	/**
	 * Enqueue assets for the plugin
	 */
	public function plugin() {
		/**
		 * SCRIPTS
		 */
		wp_enqueue_script(
			'bootstrap',
			'//cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js',
			array( 'jquery' ), 
			'5.1.3'
		);
		
		wp_enqueue_script( 
			'angular-animate', 
			'//code.angularjs.org/1.8.2/angular-animate.min.js', 
			array( 'angular' ),
			'1.8.2' 
		);		
		
		wp_enqueue_script(
			'angular-toarrayfilter', 
			'https://cdnjs.cloudflare.com/ajax/libs/angular-toarrayfilter/1.0.3/toArrayFilter.min.js', 
			array( 'angular' ),
			'1.0.3'
		);
		
		wp_enqueue_script(
			'angular-touch', 
			'//code.angularjs.org/1.8.2/angular-touch.min.js', 
			array( 'angular' ), 
			'1.8.2'
		);
		
		wp_enqueue_script( 
			'angular-ui-router', 
			'//cdnjs.cloudflare.com/ajax/libs/angular-ui-router/1.0.30/angular-ui-router.min.js', 
			array( 'angular' ),
			'1.0.30',
			true
		);
		
		wp_enqueue_script(
			'slick-carousel', 
			'//cdnjs.cloudflare.com/ajax/libs/slick-carousel/1.9.0/slick.min.js', 
			array( 'jquery' ),
			'1.9.0' 
		);
		
		wp_enqueue_script(
			'angular-slick-js', 
			'//cdnjs.cloudflare.com/ajax/libs/angular-slick-carousel/3.1.7/angular-slick.min.js', 
			array( 'jquery', 'angular', 'slick-carousel' ), 
			'3.1.7' 
		);
		
		wp_enqueue_script(
			'ace-code-editor', 
			'//cdnjs.cloudflare.com/ajax/libs/ace/1.4.13/ace.min.js', 
			array(), 
			'1.4.13' 
		);
		
		wp_enqueue_script(
			'angular-ui-ace', 
			'//cdn.jsdelivr.net/npm/angular-ui-ace@0.2.3/src/ui-ace.min.js', 
			array( 'ace-code-editor', 'angular' ), 
			'0.2.3'
		);
		
		wp_enqueue_script(
			'ui-bootstrap', 
			VENDORFUEL_ROOT_URL . 'assets/lib/js/ui-bootstrap-tpls-3.0.6.min.js', 
			array( 'angular', 'angular-animate', 'angular-touch', 'bootstrap' ), 
			'3.0.6' 
		);

		// Email Editor BEE Plugin
		wp_enqueue_script(
			'beePlugin', 
			'//app-rsrc.getbee.io/plugin/BeePlugin.js', 
			array(), 
			'1.6.3' // Version based on NPM module @mailupinc/bee-plugin version number.
		);
		
		wp_enqueue_script(
			'blob-beePlugin', 
			VENDORFUEL_ROOT_URL . 'assets/lib/beefree.io/myproject/Blob.js',
			array( 'beePlugin' ),
		);
		
		wp_enqueue_script(
			'fileSaver-beePlugin', 
			VENDORFUEL_ROOT_URL . 'assets/lib/beefree.io/myproject/fileSaver.js', 
			array( 'beePlugin' ),
		);
		
		// Papa Parse for CSV batch uploads
		wp_enqueue_script(
			'papa-parse', 
			'//unpkg.com/papaparse@5.3.0/papaparse.min.js', 
			array(), 
			'5.3.0' 
		);

		/**
		 * ANGULAR APP AND DEPENDENCIES - CONCATENATE AND MINIFY FOR PROODUCTION
		 */
		wp_enqueue_script( 
			'vendorfuel-plugin-app',
			VENDORFUEL_ROOT_URL . 'assets/app/dist/admin.min.js',
			array( 
				'angular',
				'angular-animate', 
				'angular-cookies',
				'angular-resource',
				'angular-sanitize', 
				'angular-touch', 
				'angular-ui-ace', 
				'angular-ui-router', 
				'angular-ui-tinymce', 
				'angular-slick-js', 
				'angular-local-storage', 
				'angular-toarrayfilter', 
				'bootstrap',
				'ui-bootstrap', 
			), 
			$this->plugin_data[ 'Version' ]
		);

		wp_enqueue_script( 
			'tinymce-code', 
			'//cdnjs.cloudflare.com/ajax/libs/tinymce/4.9.11/plugins/code/plugin.min.js', 
			array( 'wp-tinymce' ), 
			'4.9.11' 
		);

		wp_enqueue_script( 
			'angular-ui-tinymce', 
			'//cdnjs.cloudflare.com/ajax/libs/angular-ui-tinymce/0.0.19/tinymce.min.js', 
			array( 'angular', 'wp-tinymce' ), 
			'0.0.19' 
		);

		/**
		 * STYLES
		 */
		wp_enqueue_style(
			'bootstrap',
			'//cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css', 
			array(),
			'5.1.3'
		);

		wp_enqueue_style( 
			'sizer', 
			VENDORFUEL_ROOT_URL . 'assets/lib/css/sizer.css', 
			array(), 
			$this->plugin_data[ 'Version' ] 
		);

		wp_enqueue_style( 
			'main', 
			VENDORFUEL_ROOT_URL . 'assets/lib/css/styles.css', 
			array( 'wp-components' ), 
			$this->plugin_data[ 'Version' ] 
		);

		wp_enqueue_style( 
			'slick', 
			'//cdnjs.cloudflare.com/ajax/libs/slick-carousel/1.9.0/slick.min.css', 
			array(), 
			$this->plugin_data[ 'Version' ] 
		);

		wp_enqueue_style( 
			'slick-theme',
			'//cdnjs.cloudflare.com/ajax/libs/slick-carousel/1.9.0/slick-theme.min.css', 
			array( 'slick' ), 
			$this->plugin_data[ 'Version' ] 
		);

		/**
		 * LOCALIZED VARIABLES
		 * These variables will be available to our AngularJS application
		 */
		wp_localize_script(
			'vendorfuel-plugin-app',
			'localized',
			array(
				'apiURL' => VENDORFUEL_API_URL,
				'dir'         => array(
					'url'       => VENDORFUEL_ROOT_URL,
					'root'      => VENDORFUEL_ROOT_DIR,
					'content'   => content_url() . '/vendorfuel/',
					'templates' => VENDORFUEL_ROOT_URL . '/assets/app/templates/',
					'wpRestUrl' => get_rest_url(),
				),
				'settings'    => array(
					'general'    => $this->general_settings,
					'conversion' => get_option( 'vendorfuel-conversion-settings' ),
					'image'      => get_option( 'vendorfuel-image-settings' ),
					'store'      => get_option( 'vendorfuel-store-options' ),
				),
				'nonce'       => wp_create_nonce( 'wp_rest' ),
				'plugin_data' => $this->plugin_data
			)
		);
		wp_enqueue_media();
		wp_enqueue_editor();
	}
	/**
	 * Enqueue assets for the front-end
	 */
	public function frontend() {
		$file_path = plugin_dir_path( __DIR__ ) . 'vendorfuel.php';
		$plugin_data = get_file_data( $file_path, array(
			'Version' => 'Version'
		) );
		$version = $plugin_data['Version'];

		wp_enqueue_script(
			'ui-mask', 
			VENDORFUEL_ROOT_URL . 'assets/lib/js/mask.min.js',
			array( 'angular' ),
			'1.8.7',
			true
		);

		/*
		* BOOTSTRAP
		*/
		if ( $this->general_settings->bootstrap ) {
			wp_enqueue_script(
				'bootstrap',
				'//cdn.jsdelivr.net/npm/bootstrap@4.6.0/dist/js/bootstrap.bundle.min.js',
				array( 'jquery' ),
				'4.6.0', 
				true
			);
			wp_enqueue_style( 
				'bootstrap-css',
				'//cdn.jsdelivr.net/npm/bootstrap@4.6.0/dist/css/bootstrap.min.css', 
				array(),
				'4.6.0', 
			);
		}

		// Enqueue minimal front end styling
		wp_enqueue_style(
			'vf-frontend',
			VENDORFUEL_ROOT_URL . 'assets/lib/css/vf-frontend.css',
			array(),
			'1'
		);		

		wp_enqueue_script(
			'vendorfuel-cloud-app', 
			VENDORFUEL_ROOT_URL . 'assets/app/dist/public.min.js',
			array( 
				'angular', 
				'angular-resource',
				'angular-local-storage', 
				'angular-cookies',
				'angular-sanitize', 
				'ui-mask',
			),
			$version,
			true 
		);
		wp_enqueue_script(
			'vendorfuel-local-controllers', 
			str_replace( 'http://', 'https://',  VENDORFUEL_ROOT_URL . 'frontend/dist/vendorfuel-controllers.min.js' ), 
			array( 'angular' ),
			time(),
			true
		);


		//Google Analytics
		$analytics = json_decode(json_encode(get_option( 'vendorfuel-analytics-settings' )),true);

		if ( isset( $analytics['UA'] ) && isset( $analytics['UA']['id'] ) && $analytics['UA']['enabled'] ) {
			wp_enqueue_script(
				'vendorfuel-google-analytics',
				'https://www.googletagmanager.com/gtag/js?id=' . $analytics['UA']['id'],
			);
		}

		if ( isset( $analytics['verification'] ) && isset( $analytics['verification']['code'] ) ) {
			$google_verification_code = $analytics['verification']['code'];
			add_action(
				'wp_head',
				function () use ( $google_verification_code ) {
					?>
				<meta name="google-site-verification" content="<?php echo esc_attr( $google_verification_code ); ?>" />
					<?php
				}
			);
		}

		//Payment Gateways JS
		$enabled_payments = get_option( 'vendorfuel-enabled-payments' );
		$stripe_enabled   = false;
		if ( is_array( $enabled_payments ) ) {

			if ( array_key_exists( 'paypal', $enabled_payments ) && array_key_exists( 'paypal_checkout_enabled', $enabled_payments['paypal'] ) && $enabled_payments['paypal']['paypal_checkout_enabled'] ) {
				if ( null !== PAYPAL_CLIENT_ID && '' !== PAYPAL_CLIENT_ID ) {
					wp_enqueue_script( 
						'paypal-checkout',
						'https://www.paypal.com/sdk/js?currency=USD&client-id=' . PAYPAL_CLIENT_ID,
					);
				}
			}

			if ( array_key_exists( 'qualpay', $enabled_payments ) && array_key_exists( 'enabled', $enabled_payments['qualpay'] ) && $enabled_payments['qualpay']['enabled'] ) {
				wp_enqueue_script( 
					'qualpay-js',
					'https://app.qualpay.com/hosted/embedded/js/qp-embedded-sdk.min.js',
					array(), 
					false, 
					true 
				);
				wp_enqueue_style(
					'qualpay-css',
					'https://app.qualpay.com/hosted/embedded/css/qp-embedded.css',
				);
			}

			if ( array_key_exists( 'authnet', $enabled_payments ) && array_key_exists( 'enabled', $enabled_payments['authnet'] ) && $enabled_payments['authnet']['enabled'] ) {
				//check sandbox?
				wp_enqueue_script(
					'accept-js',
					'https://js.authorize.net/v1/Accept.js',
					array(), 
					'1', 
					true 
				);
			}
			if ( array_key_exists( 'stripe', $enabled_payments ) && array_key_exists( 'enabled', $enabled_payments['stripe'] ) && $enabled_payments['stripe']['enabled'] ) {
				wp_enqueue_script( 
					'stripe-js',
					'https://js.stripe.com/v3/',
					array(), 
					'3', 
					true 
				);
				$stripe_enabled = true;
			}

			if ( array_key_exists( 'squareup', $enabled_payments ) && array_key_exists( 'enabled', $enabled_payments['squareup'] ) && $enabled_payments['squareup']['enabled'] ) {
				//check sandbox?
				wp_enqueue_script( 
					'squareup-js',
					'https://js.squareup.com/v2/paymentform',
					array(),
					'2',
					true
				);
				wp_enqueue_style(
					'squareup-css',
					'https://api.vendorfuel.com/assets/lib/css/squareuppaymentform.css',
				);
			}
		}

		/**
		 * LOCALIZED VARIABLES
		 * These variables will be available to our AngularJS application
		 */
		$anguledit_settings = get_option( 'vendorfuel-anguledit-settings' );
		wp_localize_script(
			'vendorfuel-cloud-app',
			'localized',
			array(
				'apiURL' => VENDORFUEL_API_URL,
				'dir'      => array(
					'url'       => VENDORFUEL_ROOT_URL,
					'root'      => VENDORFUEL_ROOT_DIR,
					'content'   => content_url() . '/vendorfuel/',
					'wpRestUrl' => get_rest_url(),
				),
				'settings' => array(
					'general'            => $this->general_settings,
					'gateway'            => get_option( 'vendorfuel-gateway-settings' ),
					'analytics'          => get_option( 'vendorfuel-analytics-settings' ),
					'image'              => get_option( 'vendorfuel-image-settings' ),
					'store'              => get_option( 'vendorfuel-store-options' ),
					'stripe_pk'          => get_option( 'vendorfuel-stripe-pk' ),
					'stripe_enabled'     => $stripe_enabled,
					'authnet_public_key' => get_option( 'vendorfuel-authnet-public-key' ),
					'authnet_id'         => get_option( 'vendorfuel-authnet-id' ),
					'square_location_id' => get_option( 'vendorfuel-square-location-id' ),
				),
				'pages'    => $anguledit_settings->template_map,
			)
		);

		//Localize GET/POST parameters for punchout return
		wp_localize_script( 'vendorfuel-cloud-app', 'params', sanitize_post( array_merge( $_GET, $_POST ) ) ); // phpcs:ignore
	}
}
