<?php
/**
 * Plugin Name: VendorFuel
 * Plugin URI: https://vendorfuel.com/
 * Description: VendorFuel is a next-generation shopping cart that includes everything you need to start selling online. https://docs.vendorfuel.com
 * Version: 6.2.2
 * Author: VendorFuel
 * Author URI: https://vendorfuel.com/
 * License: GPL v3 or later
 * License URI: https://www.gnu.org/licenses/gpl-3.0.html
 */

if ( is_readable( __DIR__ . '/vendor/autoload.php' ) ) {
	include __DIR__ . '/vendor/autoload.php';
}

//STATIC VARIABLES
$general_settings = get_option( 'vendorfuel-general-settings' );
$api_url          = ( $general_settings && isset( $general_settings->api_url ) ) ? $general_settings->api_url : 'https://api.vendorfuel.com/production';
$api_key          = ( $general_settings && isset( $general_settings->api_key ) ) ? $general_settings->api_key : null;

define( 'VENDORFUEL_API_VERSION', 'v1.0.0' );
define( 'VENDORFUEL_API_URL', $api_url . "/" . VENDORFUEL_API_VERSION );
define( 'VENDORFUEL_API_KEY', $api_key );
//root directory of the vendorfuel plugin
define( 'VENDORFUEL_ROOT_DIR', plugin_dir_path( __FILE__ ) ); //root directory of the vendorfuel plugin
define( 'VENDORFUEL_ROOT_URL', plugin_dir_url( __FILE__ ) ); //root url of the vendorfuel plugin
define( 'VENDORFUEL_CONTENT_DIR', WP_CONTENT_DIR . '/vendorfuel' ); //plugin content directory

define( 'VENDORFUEL_CONTENT_URL', WP_CONTENT_URL . '/vendorfuel' ); // CAUTION: use this in local dev environment only

define( 'PAYPAL_CLIENT_ID', get_option( 'vendorfuel-paypal-id' ) );

//EXTERNAL FFUNCTIONS
require_once 'includes/class-vendorfuel-utilities.php'; //various encapsulated utilities
require_once 'includes/class-vendorfuel-enqueue.php'; //enqueue all scripts and styles; localize variables to the plugin app
require_once 'includes/class-vendorfuel-admin-page.php'; //plugin WordPress menu
require_once 'includes/class-vendorfuel-initialize.php'; //initialize app pages and settings
require_once 'includes/class-vendorfuel-wprest-api.php'; //defines all wprest api routes
require_once 'includes/class-vendorfuel-templates.php'; //update templates, sync template caches, and render template shortcodes
require_once 'includes/class-vendorfuel-queue.php'; //manages the async queue background processed
require_once 'includes/vendorfuel-widgets.php'; // Manages widgets for plugin.

//VENDORFUEL CLASS
class Vendorfuel {

	private $utilities;
	private $queue;

	public function __construct() {
		//instantiate templates and utilities classes
		$this->templates = Vendorfuel_Templates::get_instance();
		$this->utilities = Vendorfuel_Utilities::get_instance();
		$this->queue     = Vendorfuel_Queue::get_instance();
	}

	public function vendorfuel_enqueue_plugin( $hook ) {
		//enqueue the admin assets
		if ( 'toplevel_page_vendorfuel' !== $hook ) {
			return;
		}
		$assets = new Vendorfuel_Enqueue( $this->utilities );
		$assets->plugin();
	}

	public function vendorfuel_enqueue_frontend( $hook ) {
		//enqueue the front-end assets
		$assets = new Vendorfuel_Enqueue( $this->utilities );
		$assets->frontend();
	}

	public function vendorfuel_admin_init( $hook ) {
		//initialize the plugin
		$vendorfuel = new Vendorfuel_Initialize( $this->utilities );
		$vendorfuel->initialize();
	}

	public function vendorfuel_admin_menu( $hook ) {
		//admin menu
		$menu = new Vendorfuel_Admin_Page();
		$menu->register_menu();
	}

	public function vendorfuel_custom_api( $hook ) {
		//register the custom api
		$rest_api = new Vendorfuel_WPRest_Api( $this->utilities, $this->templates, $this->queue );
		$rest_api->register();
	}
}

//instantiate vendorfuel class
$js_app = new Vendorfuel();

//admin scripts
add_action( 'admin_enqueue_scripts', array( $js_app, 'vendorfuel_enqueue_plugin' ) );
add_action( 'admin_init', array( $js_app, 'vendorfuel_admin_init' ) );
add_action( 'admin_menu', array( $js_app, 'vendorfuel_admin_menu' ) );

//frontend scripts and navigation
add_action( 'wp_enqueue_scripts', array( $js_app, 'vendorfuel_enqueue_frontend' ) );

add_action( 'rest_api_init', array( $js_app, 'vendorfuel_custom_api' ) );
